<?php
namespace Teknisa\CMP\Modules\Fornecimento\Modules\ApuracaoEfetivacao\Controllers;

use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Notification;
use Teknisa\CMP\Modules\Fornecimento\Modules\ApuracaoEfetivacao\Services\ApuracaoService;
use Teknisa\CMP\Util\CmpUtilities;

class ApuracaoController extends \Teknisa\GER\Controllers\TeknisaCrud 
{
    const MESSAGES = array(
        "Vd_N_H_Qt" => 'Não há qtde. disponível nas Cotações.',
        "Vd_StCot" => 'Cotações com o status definido como "Em Andamento".',
        "Vd_Forn_Alt" => 'Existem fornecedores cotados que estão cadastrados como "Tipo de Fornecedor Alternativo".',
        "Vd_Forn_N_At" => 'Existem cotações para fornecedores inativos.',
        "ExistePrecEco_Inf" => 'Existe(m) preço(s) econômico zerado na escolha da melhor cotação.'
    );
    
    private $errors = array();
    
    public function __construct($crudService, ParameterBag $parameterBag, $connection, ApuracaoService $service, $dataSourceManager, CmpUtilities $cmpUtilities)
    {
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->connection = $connection;
        $this->service = $service;
        $this->dataSourceManager = $dataSourceManager;
        $this->cmpUtilities = $cmpUtilities;
    }
    
    public function completaProd($campo)
    {
        return str_pad($campo, 20, 'Z', STR_PAD_RIGHT);
    }
    
    public function apuracao(DTO\Request\Row $request, DTO\Response $response) 
    {
        try {
            $row = $request->getRow();
            
            $operadorComprador = $this->service->adqOperadorComprador(array('P_CDCOMPRADOR' => $row['CDOPERADOR'], 'P_CDOPERADOR'  => $row['CDOPERADORLOG']));

            $this->isOperadorRelacionado($operadorComprador);
            $this->isOperadorAutorizadoRealizarApuracao($operadorComprador);
            
            $getParam = $this->service->adqParam(array('CDFILCENTCMP' => $row['CDCENTCMP']));
            
            $params['P_OPTIMIZER_MODE'] = 'CHOOSE'; //Não é possível realizar o select na tabela V$PARAMETER
            $params['P_NRSEQAPUR'] = $this->service->generateCode('APURPRECO' . $row['CDCENTCMP']); //CODIGO GERADO
            
            $params['P_DTPROCESSA'] = self::getActualDateFormatted();//DATA DE PROCESSAMENTO
            
            $params['P_CDCENTCMP'] = $row['CDCENTCMP']; //CENTRAL DE COMPRAS
            $params['P_DTINI'] = $row['DTENTREGA']["start"]; //DATA INICIAL
            $params['P_DTFIN'] = $row['DTENTREGA']["end"]; //DATA FINAL
            $params['P_FILIPROC'] = $row['FILIPROC']; //FILIAL LOGADA
            $params['P_CDOPERADOR'] = $row['CDOPERADOR']; //OPERADOR LOGADO
            $params['P_CDFILIAL'] = 'T'; // FIXO PARA QUE O PARÂMETRO P_LISTAFILIAL SEJA PERCORRIDO NA PROCEDURE
            $params['P_CDOPERLANC'] = $row['CDOPERADORLOG']; //OPERADOR LOGADO
            $params['P_CDCOMPRADOR'] = $row['CDOPERADOR']; //COMPRADOR
            
            if ($getParam[0]["IDAPUREFESOLEXT"] == "N") {
                $params['P_EXTRA'] = "X";
            } else {
                $params['P_EXTRA'] = $row['EXTRA']; // SC EXTRA/NAO EXTRA
                
            }
            if (!empty($row['CDPRODINI'])) {
                $params['P_PRODINI'] = $row['CDPRODINI']; //PRODUTO INICIAL
                
            } else {
                $params['P_PRODINI'] = null;
            }
            if (!empty($row['CDPRODFIN'])) {
                $params['P_PRODFIN'] = $row['CDPRODFIN']; //PRODUTO FINAL
                
            } else {
                $params['P_PRODFIN'] = null;
            }
            if (!empty($row['CDGRUPFILI'])) {
                $params['P_CDGRUPFILI'] = implode("_", $row['CDGRUPFILI']); //AGRUPAMENTO DE FILIAL
                
            } else {
                $params['P_CDGRUPFILI'] = null;
            }
            if (!empty($row['CDREGIAO'])) {
                $params['P_CDREGIAO'] = "_".implode("_", $row['CDREGIAO'])."_";
            } else {
                $params['P_CDREGIAO'] = null;
            }
            if (!empty($row['LISTAFILIAL'])) {
                // '_' necessários no início e final do campo por conta da procedure
                $params['P_LISTAFILIAL'] = "_" . implode("_", $row['LISTAFILIAL']) . "_"; //FILIAIS
                
            } else {
                $params['P_LISTAFILIAL'] = 'T';
            }
            
            $param = $this->service->executeAPURA_EFETIVACAO($params);
            $param['P_NRSEQAPUR'] = $params['P_NRSEQAPUR'];
            
            if ($param['P_ROWSAFFECT'] == 'N') {
                $this->capturaErros($row);
                $response->setError(new Error($this->errors, 1));
            } else {
                $response->addDataSet(new DataSet('param', [$param]));
            }
        }
        catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function verificaPrecoEconomicoZerado(DTO\Request\Row $request, DTO\Response $response) 
    {
        $row = $request->getRow();
        
        foreach ($row['ITENS'] as $item) {
            if ($item['IDITMSELAPUR'] == 'S' && $item['PRECOECON'] <= 0) {
               $response->addMessage(new Message(self::MESSAGES['ExistePrecEco_Inf']));
               break;
            }
        }
    }
    
    public function adqCotacao(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        try {
            $params = array();
            $params['P_CDCENTCMP'] = $row['P_CDCENTCMP'];
            $params['P_NRSEQAPUR'] = $row['P_NRSEQAPUR'];
            $nrlogcorteol = $this->service->adqNrlogcorteol($params);
            if (empty($nrlogcorteol)) {
                $params['P_CDPRODESTO'] = $row['P_CDPRODESTO'];
                $response->addDataSet(new DataSet('cotacao', [$this->service->selectCotacaoWithParamNull($params) ]));
            } else {
                $params['P_CDPRODESTO'] = $row['P_CDPRODESTO'];
                $params['P_NRLOGCORTEOL'] = $nrlogcorteol;
                $response->addDataSet(new DataSet('cotacao', [$this->service->selectCotacaoWithParamNotNull($params) ]));
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function qryAutGrupOp(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $params = $this->service->qryAutGrupOp();
        
        $return['PARAM'] = "N";
        
        if (!empty($params)) {
            foreach ($params as $params) {
                if ($params["CDOPERADOR"] == $row['CDOPERADOR']) {
                    $return['PARAM'] = "S";
                }
            }
        }
        
        $response->addDataSet(new DataSet('qryAutGrupOp', $return));
    }
    
    public function melhorCotacao(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            
            $params = array(
                'P_CDCENTCMP' => $row['P_CDCENTCMP'],
                'P_NRSEQAPUR' => $row['P_NRSEQAPUR'],
                'P_SISTEMA'   => $this->cmpUtilities->getVisaoSistema(),
                'P_TIPO'      => 'F',
            );

            $this->service->executeAPURA_MELHOR_COTACAO($params);
            $response->addMessage(new Message($params['P_SISTEMA']));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function updateMelhorCotacao(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            
            if (empty($row['TXOBESCMANAP'])) {
                $param['TXOBESCMANAP'] = "";
            } else {
                $param['TXOBESCMANAP'] = $row['TXOBESCMANAP']." ";
            }
            
            if($row['IDITMSELAPUR'] == 'S') {
                $param['IDITMSELAPUR'] = 'N';
            }
            else {
                $param['IDITMSELAPUR'] = 'S';
            }
            
            $param['OLD_CDCENTITMAP'] = $row['CDCENTITMAP'];
            $param['OLD_CDPRODITMAP'] = $row['CDPRODITMAP'];
            $param['OLD_NRCOLEITMAP'] = $row['NRCOLEITMAP'];
            $param['OLD_NRSEQITMAP'] = $row['NRSEQITMAP'];
            $param['OLD_CDFORNITMAP'] = $row['CDFORNITMAP'];
            $param['OLD_CDMARCITMAP'] = $row['CDMARCITMAP'];
            $param['OLD_CDREGITMAP'] = $row['CDREGITMAP'];
            
            $this->service->beginTransaction();
            $this->service->updateMelhorCotacao($param);
            $this->service->commit();
        } catch(\Exception $e) {
            $this->service->rollback();
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function updateVrUnitario(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $params = $row['PARAMS'];
        $items = $row['ITEM'];
        $dataComHoras = true;
        
        try {
            $this->service->beginTransaction();
            
            foreach ($items as $item) {
                $item['VRPRECUNIAP_inline']  = self::transformValueMaskToFloat($item['VRPRECUNIAP_inline']);
                $item['changed_VRPRECUNIAP'] = self::transformValueMaskToFloat($item['changed_VRPRECUNIAP']);
                
                $paramsAtuaPrec['P_CDCENTCMP']      = $item['CDCENTITMAP'];
                $paramsAtuaPrec['P_CDPRODUTO']      = $item['CDPRODITMAP'];
                $paramsAtuaPrec['P_NRCOLEPRECO']    = $item['NRCOLEITMAP'];
                $paramsAtuaPrec['P_CDFORNECED']     = $item['CDFORNITMAP'];
                $paramsAtuaPrec['P_CDMARCA']        = $item['CDMARCITMAP'];
                $paramsAtuaPrec['P_CDREGIAO']       = $item['CDREGITMAP'];
                $paramsAtuaPrec['P_VRPREC']         = $item['VRPRECUNIAP_inline'];
                $this->service->acmAtuaPrec($paramsAtuaPrec);
                
                $descricao = 'Alteração de preço na tela de Apuração/Efetivação - de / para: ' . $item['changed_VRPRECUNIAP'] . ' / ' . $item['VRPRECUNIAP_inline'];
                
                $paramsLog['P_CDFILIALMCOT']        = $item['CDCENTITMAP'];
                $paramsLog['P_NRCOLEPRECOMCOT']     = $item['NRCOLEITMAP'];
                $paramsLog['P_CDMARCAMCOT']         = $item['CDMARCITMAP'];
                $paramsLog['P_CDREGIAOMCOT']        = $item['CDREGITMAP'];
                $paramsLog['P_CDFORNECEDMCOT']      = $item['CDFORNITMAP'];
                $paramsLog['P_CDPRODUTOMCOT']       = $item['CDPRODITMAP'];
                $paramsLog['P_DTOPERAITMCOT']       = self::getActualDateFormatted($dataComHoras);
                $paramsLog['P_CDOPERADORMCOT']      = $params['CDOPERADOR'];
                $paramsLog['P_DSALTERITMCOT']       = $descricao;
                $paramsLog['P_DSJUSTITMCOT']        = $descricao;
                $paramsLog['P_DSRDMUSUMCOT']        = $params['NMCONTAINER']; // Nome do container
                $paramsLog['P_DSENDUSUMCOT']        = 'Tecfood Mobile'; // Nome do produto que realizou a alteração: Tecfood Mobile
                $paramsLog['P_DSNMUSUMCOT']         = $params['NMOPERADOR']; // Nome do operador logado
                $paramsLog['P_DSMETUSUMCOT']        = 'updateVrUnitario'; // Nome do método que acionou a alteração
                $paramsLog['P_NRORG']               = $params['NRORG'];
                $paramsLog['P_IDATIVO']             = 'S';
                $this->service->insertOnMOVOPITEMCOT($paramsLog);
                
                $paramsAdqPrecEco['P_CDCENTCMP']    = $item['CDCENTITMAP'];
                $paramsAdqPrecEco['P_CDPRODUTO']    = $item['CDPRODITMAP'];
                $paramsAdqPrecEco['P_NRCOLEPRECO']  = $item['NRCOLEITMAP'];
                $paramsAdqPrecEco['P_CDFORNECED']   = $item['CDFORNITMAP'];
                $paramsAdqPrecEco['P_CDMARCA']      = $item['CDMARCITMAP'];
                $paramsAdqPrecEco['P_CDREGIAO']     = $item['CDREGITMAP'];
                $precEco = $this->service->adqPrecEco($paramsAdqPrecEco);
                
                $paramsAtuaPrecEco['P_VRPRE']       = $item['VRPRECUNIAP_inline'];
                $paramsAtuaPrecEco['P_VRPREC']      = $precEco['VRPRECECOITM'];
                $paramsAtuaPrecEco['P_VRPRECPI']    = $precEco['VRPRECOITMPI'];
                $paramsAtuaPrecEco['P_CDCENTCMP']   = $item['CDCENTITMAP'];
                $paramsAtuaPrecEco['P_CDPRODUTO']   = $item['CDPRODITMAP'];
                $paramsAtuaPrecEco['P_NRCOLEPRECO'] = $item['NRCOLEITMAP'];
                $paramsAtuaPrecEco['P_CDFORNECED']  = $item['CDFORNITMAP'];
                $paramsAtuaPrecEco['P_CDMARCA']     = $item['CDMARCITMAP'];
                $paramsAtuaPrecEco['P_CDREGIAO']    = $item['CDREGITMAP'];
                $paramsAtuaPrecEco['P_NRSEQITMAP']  = $item['NRSEQITMAP'];
                $this->service->acmAtuaPrecEco($paramsAtuaPrecEco);
                
                $emitenteAF = $this->service->adqEmitenteAF(array( 'P_CDFILIAL' => $item['CDCENTITMAP'], 'P_CDPRODUTO' => $item['CDPRODITMAP'] ));
                
                if (empty($emitenteAF)) {
                    $paramsAdqEmpresa['P_CDEMPRESA'] = null;
                } else {
                    $paramsAdqEmpresa['P_CDEMPRESA'] = $emitenteAF[0]['CDEMPRESA'];
                }
                
                $empresa = $this->service->adqEmpresa($paramsAdqEmpresa);
                
                if (empty($empresa)) {
                    $paramsProcImposto['P_EMPRESA']  = null;
                    $paramsProcImposto['P_INSCESTA'] = null;
                } else {
                    $paramsProcImposto['P_EMPRESA']  = $empresa[0]['CDEMPRESA'];
                    $paramsProcImposto['P_INSCESTA'] = $empresa[0]['CDINSCESTA'];
                }
                
                $paramsProcImposto['P_FORNECEDOR']   = $item['CDFORNITMAP'];
                $paramsProcImposto['P_FILCENT']      = $item['CDCENTITMAP'];
                $paramsProcImposto['P_LANCCOLP']     = $item['NRCOLEITMAP'];
                $paramsProcImposto['P_CDFORNECED']   = $item['CDFORNITMAP'];
                $paramsProcImposto['P_CDREGIAO']     = $item['CDREGITMAP'];
                $paramsProcImposto['P_CDPRODUTO']    = $item['CDPRODITMAP'];
                $paramsProcImposto['P_CDMARCA']      = $item['CDMARCITMAP'];
                $paramsProcImposto['P_INIVALID']     = self::getActualDateFormatted();
                $this->service->executeIMPOSTO_ITEMCOL($paramsProcImposto);
            }
            
            $this->service->commit();
        } catch(\Exception $e) {
            $this->service->rollback();
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function saveEdicaoPorEntrega(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $newItem = $row['NEW_ITEM'];
        $oldItem = $row['OLD_ITEM'];
        
        $newItem['QTACOMP'] = $this->transformValueMaskToFloat($newItem['QTACOMP']);
        $oldItem['QTACOMP'] = $this->transformValueMaskToFloat($oldItem['QTACOMP']);
        
        try {
            $this->service->beginTransaction();
            
            if ($this->validarCondicoesEdicaoPorEntrega($newItem, $oldItem)) {
                $this->saveFornecedorPorEntrega($newItem, $oldItem);
                $this->service->commit();
            }
        } catch (\Exception $e) {
            $this->service->rollback();
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function incluirPorEntrega(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $newItem = $row['NEW_ITEM'];
        $oldItem = $row['OLD_ITEM'];
        
        $newItem['QTACOMP'] = $this->transformValueMaskToFloat($newItem['QTACOMP']);
        $oldItem['QTACOMP'] = $this->transformValueMaskToFloat($oldItem['QTACOMP']);
        
        $newItem['IDITMSELAPUR'] = 'S';
        try {
            $this->service->beginTransaction();
            if ($this->validarCondicoesInclusaoPorEntrega($newItem, $oldItem)) {
                $this->saveFornecedorPorEntrega($newItem, $oldItem);
                $this->service->commit();
            }
        } catch (\Exception $e) {
            $this->service->rollback();
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    private function validarCondicoesEdicaoPorEntrega($newItem, $oldItem) {
        $this->isQuantidadeEntregaPreenchida($newItem['QTACOMP']);
        $this->isQuantidadeEntregaZerada($newItem['QTACOMP']);
        
        return $this->isQuantidadeEntregaIgual($newItem['QTACOMP'], $oldItem['QTACOMP']);
    }
    
    private function validarCondicoesInclusaoPorEntrega($newItem, $oldItem) {
        $this->isQuantidadeEntregaPreenchida($newItem['QTACOMP']);
        $this->isQuantidadeEntregaZerada($newItem['QTACOMP']);
        
        return true;
    }
    
    private function isQuantidadeEntregaPreenchida($quantidade) {
        if (empty($quantidade)) {
            throw new \Exception('Quantidade para entrega deve ser informada.');
        }
    }
    
    private function isQuantidadeEntregaZerada($quantidade) {
        if ($quantidade == 0) {
            throw new \Exception('Quantidade para entrega deve ser maior que zero.');
        }
    }
    
    private function isQuantidadeEntregaIgual($newQtde, $oldQtde) {
        if ($newQtde == $oldQtde) {
            return false;
        }
        
        return true;
    }
    
    private function saveFornecedorPorEntrega($newItem, $oldItem) {
        $params['QTACOMP']          = $newItem['QTACOMP']; // (FLOAT,IN)=5 
        $params['IDITMSELAPUR']     = $newItem['IDITMSELAPUR']; // (VARCHAR[1],IN)='S' 
        $params['TXOBESCMANAP']     = null; // (VARCHAR[0],IN)=<NULL> 
        $params['OLD_CDCENTITMAP']  = $oldItem['CDCENTITMAP']; // (VARCHAR[4],IN)='9999' 
        $params['OLD_DTENTRAPUT']   = $oldItem['DTENTRAPUT']; // (DATE,IN)='11/02/2019' 
        $params['OLD_CDPRODITMAP']  = $oldItem['CDPRODITMAP']; // (VARCHAR[10],IN)='1070267603' 
        $params['OLD_NRCOLEITMAP']  = $oldItem['NRCOLEITMAP']; // (VARCHAR[10],IN)='0000004346' 
        $params['OLD_NRSEQITMAP']   = $oldItem['NRSEQITMAP']; // (VARCHAR[10],IN)='0000012251' 
        $params['OLD_CDFILIAP']     = $oldItem['CDFILIAP']; // (VARCHAR[4],IN)='1002' 
        $params['OLD_CDFORNITMAP']  = $oldItem['CDFORNITMAP']; // (VARCHAR[15],IN)='J17710198000108' 
        $params['OLD_CDMARCITMAP']  = $oldItem['CDMARCITMAP']; // (VARCHAR[5],IN)='00001' 
        $params['OLD_CDREGITMAP']   = $oldItem['CDREGITMAP']; // (VARCHAR[3],IN)='001'
        $this->service->acmUpdItmApurPrec($params);
    }
    
    public function compValidation(DTO\Request\Row $request, DTO\Response $response) {
        try{
            
            $row = $request->getRow();
        
            $passwordAut['PARAM'] = $this->verificaUsoDeSenhaOperadorRelacionado($row) ? 'S' : 'N';
        
            $response->addDataSet(new DataSet('passwordAut', $passwordAut));
            
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
        
    }
    
    private function isOperadorAutorizadoRealizarApuracao($operadorComprador) {
        if ($operadorComprador[0]['IDAPURCMPOPER'] == 'N') {
            throw new \Exception("Operador não autorizado a realizar apuração para o comprador.", 1);
        }
        
        return true;
    }
    
    private function isOperadorRelacionado($operadorComprador) {
        if (empty($operadorComprador)) {
            throw new \Exception("Operador não relacionado ao comprador.", 1);
        }
    
        return true;
    }
    
    private function verificaUsoDeSenhaOperadorRelacionado($row) {
        $operRelacResult = $this->service->qryOperRelacAux(array('P_CDCOMPRADOR' => $row['CDCOMPRADOR']));
        $adqParamResult = $this->service->adqParam(array('CDFILCENTCMP' => $row['CDCENTCMP']));
        
        if (empty($operRelacResult)) {
            if ($adqParamResult[0]['IDSISDOS'] != 3) {
                return true;
            }
        } else {
            $operadorComprador = $this->service->adqOperadorComprador(array('P_CDCOMPRADOR' => $row['CDCOMPRADOR'], 'P_CDOPERADOR'  => $row['CDOPERADOR']));
            
            $this->isOperadorRelacionado($operadorComprador);
            $this->isOperadorAutorizadoRealizarApuracao($operadorComprador);
            
            if ($operadorComprador[0]['IDEXSENHCMPOPER'] == 'S') {
                return true;
            }
        }
        
        return false;
    }
    
    public function passwordValidation(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $dataSourceName = 'operador';
        $conditions = array(array('columnName' => 'CDOPERADOR', 'operator' => '=', "value" => $row['CDOPERADOR']));
        $dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
        if (md5($row['PASSWORD']) != $dataSet[0]['CDSENHAOPERWEB']) {
            $response->setError(new Error("Senha inválida", 1));
        }
    }
    
    public function getParams(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $return = array();
        $return[0] = $this->service->centralCompras(array( 'CDFILIAL' => $row['CDFILIAL'] ));
        $return[1] = $this->service->adqParam(array( 'CDFILCENTCMP' => $return[0][0]['CDFILCENTCMP'] ));
        $return[2] = $this->service->adqParamCmp(array( 'CDFILCENTCMP' => $return[0][0]['CDFILCENTCMP'] ));

        $response->addDataSet(new DataSet('getParams', $return));
    }
    
    private function capturaErros($row) {
        $params = array(
            "P_CDCENTCMP"   => $row["CDCENTCMP"],
            "P_CDPRODINI"   => $row["CDPRODINI"],
            "P_CDPRODFIN"   => str_pad($row["CDPRODFIN"], 20, 'Z', STR_PAD_RIGHT),
            "P_DATAINI"     => $row["DTENTREGA"]["start"],
            "P_DATAFIN"     => $row["DTENTREGA"]["end"]
        );
        
        $sistema = $this->cmpUtilities->getVisaoSistema();

        if ($sistema == 'SUP') {
            $params["P_CDOPERADOR"] = $row["CDOPERADOR"];
            $params["P_ITEM"] = "T";
        } else {
            $params["P_CDOPERADOR"] = "T";
            $params["P_ITEM"] = "S";
        }
        
        if (empty($params['P_CDPRODINI']) || empty($params['P_CDPRODFIN'])) {
           $params['P_CDPRODINI'] = '0';
           $params['P_CDPRODFIN'] = 'ZZZZZZZZZZ';
        }
        
        if (empty($row["CDREGIAO"])) {
            $params["P_CDREGIAO"] = "T";
        } else {
            $params["P_CDREGIAO"] = implode("_", $row["CDREGIAO"]);
        }
        
        $itemCole = $this->service->adqItemCole($params);
        
        if ($itemCole["QTDISPPRODMARC"] == 1) {
            $this->addError("Vd_N_H_Qt");
        }
        
        if ($itemCole["IDSITUCOLETA"] == 1) {
            $this->addError("Vd_StCot");
        }
        
        if ($itemCole["IDTIPOFORN"] == 1) {
            $this->addError("Vd_Forn_Alt");
        }
        
        if ($itemCole["IDSITUCADA"] == 1) {
            $this->addError("Vd_Forn_N_At");
        }
    }
    
    private function addError($errorType) {
        array_push($this->errors, self::MESSAGES[$errorType]);
    }
    
    public function transformValueMaskToFloat($value) {
        if (gettype($value) == 'string') {
            $arrayReplace = array('R$', '.');
            $value = str_replace($arrayReplace, '', $value);
            $value = str_replace(',', '.', $value);
        }
        
        return (float) $value;
    }
    
    public function completaNumeroComZeroEsquerda($numero) {
        return str_pad($numero, 2, '0', STR_PAD_LEFT);
    }
    
    /**
     * Formata a data atual no padrão brasileiro 24hrs.
     * @param {boolean} $getDataComHoras Se for true, retorna a data com as horas. Caso contrário, retorna somente a data.
     * 
     * @return {string} Retorna a data formatada.
     */
    public function getActualDateFormatted($getDataComHoras = false) {
        $actualDate = getdate();
        
        $dayFormatted   = self::completaNumeroComZeroEsquerda($actualDate['mday']);
        $monthFormatted = self::completaNumeroComZeroEsquerda($actualDate['mon']);
        
        if ($getDataComHoras) {
            $hourFormatted       = self::completaNumeroComZeroEsquerda($actualDate['hours']);
            $minuteFormatted     = self::completaNumeroComZeroEsquerda($actualDate['minutes']);
            $secondFormatted     = self::completaNumeroComZeroEsquerda($actualDate['seconds']);
            
            $actualDateFormatted = $dayFormatted.'/'.$monthFormatted.'/'.$actualDate['year'].' '.$hourFormatted.':'.$minuteFormatted.':'.$secondFormatted;
        } else {
            $actualDateFormatted = $dayFormatted.'/'.$monthFormatted.'/'.$actualDate['year'];
        }
        
        return $actualDateFormatted;
    }
}
