<?php
namespace Teknisa\CMP\Modules\Fornecimento\Modules\AutorizacaoFornecimento\Services;

use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use \Teknisa\Model\Suprimentos\Entities\Itemautf;
use \Teknisa\Model\Suprimentos\Entities\Autoforne;

class Sup05100AnaliseAFService 
{
    const EMAIL_COOKIE_NAME = 'MAIL_BODY_CONCLUIR_ANALISE';
    const ATIVO = 'S';

    protected $entityManager;
    protected $connection;
    protected $environment;
    protected $newCode;

    public function __construct($entityManager, $environment, $newCode) 
    {
        $this->entityManager = $entityManager;
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
        $this->newCode = $newCode;
    }
    
    
    public function iniciaConexao() {
        $this->connection->beginTransaction();
    }
    
    
    public function realizaFlush() {
        $this->entityManager->flush();
    }
    
    
    public function realizaCommit() {
        $this->connection->commit();
    }


    public function realizaRollback() {
        $this->connection->rollBack();
    }
    
    
    public function executaSql($sql, $params, $consulta = true) {
        try{
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
            if($consulta == true) {
                return $std->fetchAll();
            }
            
            return true;
        } catch (\Exception $e){
            throw $e;
        } 
    }
    
    
    public function novoCodigo($chave) {
        
        return $this->newCode->getCodeByTableName($chave, $this->environment->getNrOrg());
        
    }
    
    public function retornaOperadorRelacionado($cdcomprador) {
        $select = "SELECT CDOPERADOR, IDEXSENHCMPOPER, IDCOTCMPOPER, IDAPURCMPOPER, IDAFCMPOPER FROM COMPROPER WHERE CDCOMPRADOR = :P_CDCOMPRADOR AND NRORG = :NRORG";
        
        $params = [
            "P_CDCOMPRADOR" => $cdcomprador,
            "NRORG"         => $this->environment->getNrOrg()
        ];
        
        $operadorRelacionado = self::executaSql($select, $params);
        
        return $operadorRelacionado;
    }
    
    public function retornaIdsisdos() {
        $select = "SELECT IDSISDOS FROM PARAMGERAL WHERE NRORG = :NRORG";
        
        $params = [
            "NRORG" => $this->environment->getNrOrg()
        ];
        
        $idsisdos = self::executaSql($select, $params);
        
        return is_array($idsisdos) && count($idsisdos) ? $idsisdos[0]['IDSISDOS'] : false;
    }
    
    
    public function retornaCentralCompras($cdfilial) {
        $select = "SELECT NVL(FILIAL.CDFILCENTCMP,FILIAL.CDFILIAL) AS CDFILCENTCMP FROM FILIAL WHERE FILIAL.CDFILIAL = :CDFILIAL AND FILIAL.NRORG = :NRORG";
        
        $params = [
            "CDFILIAL" => $cdfilial,
            "NRORG" => $this->environment->getNrOrg()
        ];
        
        $cdfilcentcmp = self::executaSql($select, $params);
        
        return is_array($cdfilcentcmp) && count($cdfilcentcmp) ? $cdfilcentcmp[0]['CDFILCENTCMP'] : false;
    }
    
    
    public function retornaParasupri($cdfilial) {
        $select = "SELECT PARASUPRI.CDFILIAL, NVL(FILIAL.CDFILCENTCMP,FILIAL.CDFILIAL) AS CDFILCENTCMP, FIL.NMFILIAL AS NMFILCENTCMP, NVL(IDUTILCONSSOLIOL,'S') IDUTILCONSSOLIOL, NVL(IDUTDADOPERENVEMAIL,'LOGIN_FILIAL_REMETENTE_FILIAL') IDUTDADOPERENVEMAIL, NVL(IDENVIAEMAILFORNSMTP,'A') IDENVIAEMAILFORNSMTP, NVL(IDUTLPRCMPATIVO,'N') IDUTLPRCMPATIVO, NVL(IDCONFREMANEJAF,'N') IDCONFREMANEJAF, PARASUPRI.NRORG FROM PARASUPRI, FILIAL FIL, FILIAL WHERE FILIAL.CDFILIAL = :CDFILIAL AND FILIAL.NRORG = :NRORG AND NVL(FILIAL.CDFILCENTCMP,FILIAL.CDFILIAL) = FIL.CDFILIAL AND FIL.CDFILIAL = PARASUPRI.CDFILIAL AND FILIAL.NRORG = FIL.NRORG AND FIL.NRORG = PARASUPRI.NRORG";
        
        $params = [
            "CDFILIAL" => $cdfilial,
            "NRORG" => $this->environment->getNrOrg()
        ];
        
        $parasupri = self::executaSql($select, $params);
        
        return is_array($parasupri) && count($parasupri) ? $parasupri[0] : false;
    }
    
    
    public function retornaFilialOL($cdfildest) {
        $select = "SELECT FILIAL.IDFUNCAOFILI FROM FILIAL WHERE FILIAL.CDFILIAL = :CDFILDEST AND FILIAL.NRORG = :NRORG";
                      
        $params = [
            "CDFILDEST" => $cdfildest,
            "NRORG"     => $this->environment->getNrOrg()
        ];
        
        $filialOL = self::executaSql($select, $params);

        return is_array($filialOL) && count($filialOL) ? $filialOL[0]['IDFUNCAOFILI'] : false;
    }
    
    
    public function retornaIdUtilizaCalendario($cdforneced, $cdfilial) {
        $select = "SELECT NVL(MAX(REFORFIL.IDUTCALENDCMPGERACAOAF),'N') IDUTCALENDCMPGERACAOAF FROM REFORFIL WHERE REFORFIL.CDFORNECED = :CDFORNECED AND REFORFIL.CDFILIAL = :CDFILIAL AND REFORFIL.NRORG = :NRORG";
                      
        $params = [
            "CDFORNECED" => $cdforneced,
            "CDFILIAL"   => $cdfilial,
            "NRORG"      => $this->environment->getNrOrg()
        ];
        
        $idUtilizaCalendario = self::executaSql($select, $params);
        
        return is_array($idUtilizaCalendario) && count($idUtilizaCalendario) ? $idUtilizaCalendario[0]['IDUTCALENDCMPGERACAOAF'] : false;
    }
    
    
    public function retornaIdconsolapuefet($cdfilcentcmp, $nrapurprec) {
        $select = "SELECT APURPRECO.IDCONSOLAPUEFET FROM APURPRECO WHERE APURPRECO.CDFILCENTCMP = :CDFILCENTCMP AND APURPRECO.NRAPURPREC = :NRAPURPREC AND APURPRECO.NRORG = :NRORG";
                      
        $params = [
            "CDFILCENTCMP" => $cdfilcentcmp,
            "NRAPURPREC" => $nrapurprec,
            "NRORG"      => $this->environment->getNrOrg()
        ];
        
        $idconsolapuefet = self::executaSql($select, $params);
        
        return count($idconsolapuefet) ? $idconsolapuefet[0]['IDCONSOLAPUEFET'] : false;
    }
    
    
    public function retornaExisteItemAF($cdfildest, $cdfillanc, $nreqapuraf, $cdproduto, $dtprogentaf) {
        $select = "SELECT MAX(I.NRAUTOFORN) NRAUTOFORN FROM AUTOFORNE A, ITEMAUTF I WHERE I.CDFILDEST = :CDFILDEST AND I.CDFILLANC = :CDFILLANC AND NRSEQAPURAF = :NRSEQAPURAF AND I.CDPRODUTO = :CDPRODUTO AND I.DTPROGENTAF = TO_DATE(:DTPROGENTAF, 'DD/MM/YYYY') AND I.NRORG = :NRORG AND I.CDFILDEST = A.CDFILDEST AND I.CDFILLANC = A.CDFILLANC AND I. NRAUTOFORN = A.NRAUTOFORN AND I. NRORG = A.NRORG";
                      
        $params = [
            "CDFILDEST"     => $cdfildest,
            "CDFILLANC"     => $cdfillanc,
            "NRSEQAPURAF"   => $nreqapuraf,
            "CDPRODUTO"     => $cdproduto,
            "DTPROGENTAF"   => $dtprogentaf,
            "NRORG"         => $this->environment->getNrOrg()
        ];
        
        $exiteItemAf = self::executaSql($select, $params);
        
        return is_array($exiteItemAf) && count($exiteItemAf) ? true : false;
    }
    
    
    public function retornaAutoforne($cdfildest, $cdfillanc, $nrautoforn) {
        
        $autoforne = $this->entityManager->getRepository('\Teknisa\Model\Suprimentos\Entities\Autoforne')
            ->findOneBy(array(
                'cdfildest' => $cdfildest,
                'cdfillanc' => $cdfillanc,
                'nrautoforn' => $nrautoforn,
                'nrorg' => $this->environment->getNrOrg()
            ));
        
        $autoforne = $autoforne instanceof Autoforne ? $autoforne : false;
        
        return $autoforne;
        
    }
    
    
    public function retornaListaItemAutfAF($cdfildest, $cdfillanc, $nrautoforn) {
        
        $itemautf = $this->entityManager->getRepository('\Teknisa\Model\Suprimentos\Entities\Itemautf')
            ->findBy(array(
                'cdfildest' => $cdfildest,
                'cdfillanc' => $cdfillanc,
                'nrautoforn' => $nrautoforn,
                'nrorg' => $this->environment->getNrOrg()
            ));
        
        $itemautf = is_array($itemautf) && count($itemautf) ? $itemautf : false;
        
        return $itemautf;
        
    }
    
    
    public function retornaItemAfDest($cdfildest, $cdfillanc, $nrautoforn, $cdproduto, $cdmarca, $dtprogentaf) {
        
        $select = "SELECT CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, CDMARCA, DTPROGENTAF, QTPROGENTAF FROM ITEMAUTF WHERE CDFILDEST = :CDFILDEST AND CDFILLANC = :CDFILLANC AND NRAUTOFORN = :NRAUTOFORN AND CDPRODUTO = :CDPRODUTO AND CDMARCA = :CDMARCA AND NRORG = :NRORG AND DTPROGENTAF = TO_DATE(:DTPROGENTAF, 'DD/MM/YYYY')";
        
        $params = [
            "CDFILDEST"     => $cdfildest,
            "CDFILLANC"     => $cdfillanc,
            "NRAUTOFORN"    => $nrautoforn,
            "CDPRODUTO"     => $cdproduto,
            "CDMARCA"       => $cdmarca,
            "DTPROGENTAF"   => $dtprogentaf,
            "NRORG"         => $this->environment->getNrOrg()
        ];
        
        $itemAfDest = self::executaSql($select, $params);

        return is_array($itemAfDest) && count($itemAfDest) ? $itemAfDest[0] : false;
        
    }
    
    
    public function retornaQuantidadeItemNF($cdfildest, $cdfillanc, $nrautoforn) {
        
        $select = "SELECT COUNT(*) COUNT, ITEMAUTF.NRLANCTONF FROM ITEMAUTF WHERE CDFILDEST = :CDFILDEST AND CDFILLANC = :CDFILLANC AND NRAUTOFORN = :NRAUTOFORN AND NRORG = :NRORG GROUP BY ITEMAUTF.NRLANCTONF";
        
         $params = [
            "CDFILDEST"     => $cdfildest,
            "CDFILLANC"     => $cdfillanc,
            "NRAUTOFORN"    => $nrautoforn,
            "NRORG"         => $this->environment->getNrOrg()
        ];
        
        $itemNF = self::executaSql($select, $params);
        
        return $itemNF[0];
        
    }
    
    
    public function retornaProdutos($cdfildest, $cdfillanc, $nrseqapuraf, $nrautoforn) {
        
        $select = "SELECT CDFILDEST, CDFILLANC, NRAUTOFORN, DTPROGENTAF, DTENTRITMSOL, CDPRODUTO, CDARVPROD, NMPRODUTO, CDPRODESTO, VRFATOCONV, CDMARCA, NMMARCA, QTPROGENTAF, VRPREUNIAF, IDBAIXAAF, SUBSTR(SGQTPRODFORN,1,INSTR(SGQTPRODFORN,'¿') - 1) AS SGUNIDADE, TO_NUMBER(SUBSTR(SGQTPRODFORN,INSTR(SGQTPRODFORN,'¿') + 1,INSTR(SGQTPRODFORN,'ø') - INSTR(SGQTPRODFORN,'¿') - 1)) AS QTMINAF, DECODE(SUBSTR(SGQTPRODFORN,INSTR(SGQTPRODFORN,'¿') + 1,LENGTH(SGQTPRODFORN) ),NULL,'N','S') AS IDPRODFORN, NRDIASVALPRFORN, DSINCONSITAF, MARCA, IDMOTPRESCAF, IDTIPOLANITM, NRCOTPREITAF, NRLISTAITAF, DTUTILIZA, QTSOLIPROD, SGUNIDSOLI, QTPROGENTAF * VRPREUNIAF VRPRETOTAF, NRORG FROM( SELECT ITEMAUTF.NRORG, ITEMAUTF.CDFILDEST, ITEMAUTF.CDFILLANC, ITEMAUTF.NRAUTOFORN, ITEMAUTF.DTPROGENTAF, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PRODUTO.CDPRODESTO, PRODUTO.VRFATOCONV, ITEMAUTF.CDMARCA, MARCA.NMMARCA, ITEMAUTF.QTPROGENTAF, ITEMAUTF.VRPREUNIAF, AUTOFORNE.IDBAIXAAF, ( SELECT MAX(PRODFORN.SGUNIDADE || '¿' || PRODFORN.QTMINAF || 'ø' || PRODFORN.CDFORNECED) FROM PRODFORN, PRODUTO PFPROD WHERE AUTOFORNE.CDFORNECED = PRODFORN.CDFORNECED AND PRODFORN.CDPRODUTO = PFPROD.CDPRODUTO AND PFPROD.CDARVPROD = ( SELECT MAX(PFPRPRODNV.CDARVPROD) FROM PRODFORN PFPRODNV, PRODUTO PFPRPRODNV WHERE AUTOFORNE.CDFORNECED = PFPRODNV.CDFORNECED AND PFPRPRODNV.CDPRODUTO = PFPRODNV.CDPRODUTO AND PRODUTO.CDARVPROD LIKE PFPRPRODNV.CDARVPROD || '%' ) ) AS SGQTPRODFORN, ( SELECT MIN(I.DTUTILIZA) FROM ITEMSOLI I, PRODUTO P WHERE I.CDFILSOLI = ITEMAUTF.CDFILDEST AND I.CDPRODUTO = P.CDPRODUTO AND P.CDPRODESTO = PRODUTO.CDPRODESTO AND NVL(I.IDITMCONS,'N') = 'N' AND NVL(I.IDSOLIAPROV,'S') = 'S' AND I.CDFILIOPELOG IS NULL AND ( ( I.IDITMSOLEXTRA = APURPRECO.IDCONSOLAPUEFET ) OR ( APURPRECO.IDCONSOLAPUEFET = 'X' ) ) AND I.DTPROGENTR = ITEMAUTF.DTENTRITMSOL ) AS DTUTILIZA, ( SELECT SUM(I.QTSOLIPROD * NVL(P.VRFATOCONV,1) ) FROM ITEMSOLI I, PRODUTO P WHERE I.CDFILSOLI = ITEMAUTF.CDFILDEST AND I.CDPRODUTO = P.CDPRODUTO AND P.CDPRODESTO = PRODUTO.CDPRODESTO AND NVL(I.IDITMCONS,'N') = 'N' AND NVL(I.IDSOLIAPROV,'S') = 'S' AND I.CDFILIOPELOG IS NULL AND ( ( I.IDITMSOLEXTRA = APURPRECO.IDCONSOLAPUEFET ) OR ( APURPRECO.IDCONSOLAPUEFET = 'X' ) ) AND I.DTPROGENTR = ITEMAUTF.DTENTRITMSOL ) AS QTSOLIPROD, ( SELECT MAX(PROD.SGUNIDADE) FROM PRODUTO PROD WHERE PROD.CDPRODUTO = PRODUTO.CDPRODESTO ) AS SGUNIDSOLI, ( SELECT MAX(PRODFORNCOMP.NRDIASVALPRFORN) FROM PRODFORNCOMP WHERE AUTOFORNE.CDFORNECED = PRODFORNCOMP.CDFORNECED AND PRODFORNCOMP.CDPRODCOMPL = ITEMAUTF.CDPRODUTO ) AS NRDIASVALPRFORN, ITEMAUTF.DSINCONSITAF, MARCA.CDMARCA || ' - ' || MARCA.NMMARCA AS MARCA, ITEMAUTF.IDMOTPRESCAF, ITEMAUTF.IDTIPOLANITM, ITEMAUTF.NRCOTPREITAF, ITEMAUTF.NRLISTAITAF FROM PRODUTO, MARCA, ITEMAUTF, APURPRECO, AUTOFORNE WHERE NVL(AUTOFORNE.IDAFOPERLOG,'2') = '2' AND NVL(AUTOFORNE.IDAFPRODWEB,'N') = 'N' AND AUTOFORNE.CDFILDEST =:CDFILDEST AND AUTOFORNE.CDFILLANC =:CDFILLANC AND AUTOFORNE.NRSEQAPURAF =:NRSEQAPURAF AND ITEMAUTF.NRAUTOFORN =:NRAUTOFORN AND ( ( APURPRECO.CDFILCENTCMP =:CDFILLANC ) OR ( APURPRECO.CDFILLANC =:CDFILLANC ) ) AND APURPRECO.NRAPURPREC =:NRSEQAPURAF AND AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN AND ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO AND ITEMAUTF.CDMARCA = MARCA.CDMARCA AND ITEMAUTF.NRORG =:NRORG ) ORDER BY DTPROGENTAF, NMPRODUTO, CDMARCA";


        $params = [
            "CDFILDEST"     => $cdfildest,
            "CDFILLANC"     => $cdfillanc,
            "NRSEQAPURAF"   => $nrseqapuraf,
            "NRAUTOFORN"    => $nrautoforn,
            "NRORG"         => $this->environment->getNrOrg()
        ];
        
        $produtos = self::executaSql($select, $params);
        
        return is_array($produtos) && count($produtos) ? $produtos : false;
        
    }
    
    
    public function retornaProdutosOL($cdfildest, $cdfillanc, $nrseqapuraf, $nrautoforn) {
        
        $select = "SELECT CDFILDEST, CDFILLANC, NRAUTOFORN, DTPROGENTAF, DTENTRITMSOL, CDPRODUTO, CDARVPROD, NMPRODUTO, CDPRODESTO, VRFATOCONV, CDMARCA, NMMARCA, QTPROGENTAF, VRPREUNIAF, IDBAIXAAF, SUBSTR(SGQTPRODFORN,1,INSTR(SGQTPRODFORN,'¿') - 1) AS SGUNIDADE, TO_NUMBER(SUBSTR(SGQTPRODFORN,INSTR(SGQTPRODFORN,'¿') + 1,INSTR(SGQTPRODFORN,'ø') - INSTR(SGQTPRODFORN,'¿') - 1)) AS QTMINAF, DECODE(SUBSTR(SGQTPRODFORN,INSTR(SGQTPRODFORN,'¿') + 1,LENGTH(SGQTPRODFORN) ),NULL,'N','S') AS IDPRODFORN, NRDIASVALPRFORN, DSINCONSITAF, MARCA, IDMOTPRESCAF, IDTIPOLANITM, NRCOTPREITAF, NRLISTAITAF, DTUTILIZA, QTSOLIPROD, SGUNIDSOLI, QTPROGENTAF * VRPREUNIAF VRPRETOTAF, NRORG FROM( SELECT ITEMAUTF.NRORG, ITEMAUTF.CDFILDEST, ITEMAUTF.CDFILLANC, ITEMAUTF.NRAUTOFORN, ITEMAUTF.DTPROGENTAF, ITEMAUTF.DTENTRITMSOL, PRODUTO.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PRODUTO.CDPRODESTO, PRODUTO.VRFATOCONV, ITEMAUTF.CDMARCA, MARCA.NMMARCA, ITEMAUTF.QTPROGENTAF, ITEMAUTF.VRPREUNIAF, AUTOFORNE.IDBAIXAAF, ( SELECT MAX(PRODFORN.SGUNIDADE || '¿' || PRODFORN.QTMINAF || 'ø' || PRODFORN.CDFORNECED) FROM PRODFORN, PRODUTO PFPROD WHERE AUTOFORNE.CDFORNECED = PRODFORN.CDFORNECED AND PRODFORN.CDPRODUTO = PFPROD.CDPRODUTO AND PFPROD.CDARVPROD = ( SELECT MAX(PFPRPRODNV.CDARVPROD) FROM PRODFORN PFPRODNV, PRODUTO PFPRPRODNV WHERE AUTOFORNE.CDFORNECED = PFPRODNV.CDFORNECED AND PFPRPRODNV.CDPRODUTO = PFPRODNV.CDPRODUTO AND PRODUTO.CDPRODUTORIG LIKE PFPRPRODNV.CDARVPROD || '%' ) ) AS SGQTPRODFORN, ( SELECT MIN(I.DTUTILIZA) FROM ITEMSOLI I, PRODUTO P WHERE I.CDFILSOLI = ITEMAUTF.CDFILDEST AND I.CDPRODUTO = P.CDPRODUTO AND P.CDPRODESTO = PRODUTO.CDPRODESTO AND NVL(I.IDITMCONS,'N') = 'N' AND NVL(I.IDSOLIAPROV,'S') = 'S' AND I.CDFILIOPELOG IS NULL AND ( ( I.IDITMSOLEXTRA = APURPRECO.IDCONSOLAPUEFET ) OR ( APURPRECO.IDCONSOLAPUEFET = 'X' ) ) AND I.DTPROGENTR = ITEMAUTF.DTENTRITMSOL ) AS DTUTILIZA, ( SELECT SUM(I.QTSOLIPROD * NVL(P.VRFATOCONV,1) ) FROM ITEMSOLI I, PRODUTO P WHERE I.CDFILSOLI = ITEMAUTF.CDFILDEST AND I.CDPRODUTO = P.CDPRODUTO AND P.CDPRODESTO = PRODUTO.CDPRODESTO AND NVL(I.IDITMCONS,'N') = 'N' AND NVL(I.IDSOLIAPROV,'S') = 'S' AND I.CDFILIOPELOG IS NULL AND ( ( I.IDITMSOLEXTRA = APURPRECO.IDCONSOLAPUEFET ) OR ( APURPRECO.IDCONSOLAPUEFET = 'X' ) ) AND I.DTPROGENTR = ITEMAUTF.DTENTRITMSOL ) AS QTSOLIPROD, ( SELECT MAX(PROD.SGUNIDADE) FROM PRODUTO PROD WHERE PROD.CDPRODUTO = PRODUTO.CDPRODESTO ) AS SGUNIDSOLI, ( SELECT MAX(PRODFORNCOMP.NRDIASVALPRFORN) FROM PRODFORNCOMP WHERE AUTOFORNE.CDFORNECED = PRODFORNCOMP.CDFORNECED AND PRODFORNCOMP.CDPRODCOMPL = ITEMAUTF.CDPRODUTO ) AS NRDIASVALPRFORN, ITEMAUTF.DSINCONSITAF, MARCA.CDMARCA || ' - ' || MARCA.NMMARCA AS MARCA, ITEMAUTF.IDMOTPRESCAF, ITEMAUTF.IDTIPOLANITM, ITEMAUTF.NRCOTPREITAF, ITEMAUTF.NRLISTAITAF FROM ( SELECT PRODUTO.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PRODUTO.CDPRODESTO, PRODUTO.VRFATOCONV, PRODUTORIG.CDARVPROD CDARVPRODORIG, PRODUTORIG.CDPRODUTO CDPRODUTORIG FROM PRODUTO, RELACPRODOL, PRODUTO PRODUTORIG WHERE PRODUTO.CDPRODUTO = RELACPRODOL.CDPRODARVOL AND PRODUTORIG.CDPRODUTO = RELACPRODOL.CDPRARVORIG ) PRODUTO, MARCA, ITEMAUTF, APURPRECO, AUTOFORNE WHERE NVL(AUTOFORNE.IDAFOPERLOG,'2') = '2' AND NVL(AUTOFORNE.IDAFPRODWEB,'N') = 'N' AND AUTOFORNE.CDFILDEST =:CDFILDEST AND AUTOFORNE.CDFILLANC =:CDFILLANC AND AUTOFORNE.NRSEQAPURAF =:NRSEQAPURAF AND ITEMAUTF.NRAUTOFORN = :NRAUTOFORN AND ( ( APURPRECO.CDFILCENTCMP =:CDFILLANC ) OR ( APURPRECO.CDFILLANC =:CDFILLANC )) AND APURPRECO.NRAPURPREC =:NRSEQAPURAF AND AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN AND ITEMAUTF.CDPRODUTO = PRODUTO.CDPRODUTO AND ITEMAUTF.CDMARCA = MARCA.CDMARCA AND ITEMAUTF.NRORG =:NRORG ) ORDER BY DTPROGENTAF, NMPRODUTO, CDMARCA";
                      
        $params = [
            "CDFILDEST"     => $cdfildest,
            "CDFILLANC"     => $cdfillanc,
            "NRSEQAPURAF"   => $nrseqapuraf,
            "NRAUTOFORN"    => $nrautoforn,
            "NRORG"         => $this->environment->getNrOrg()
        ];
        
        $produtosOL = self::executaSql($select, $params);
        
        return is_array($produtosOL) && count($produtosOL) ? $produtosOL : false;
        
    }
    
    
    public function retornaRelacProdOl($cdproduto, $cdmarca) {
        
        $select = "SELECT RELACPRODOL.CDPRARVORIG, RELACPRODOL.CDMARCA FROM RELACPRODOL, PRODUTO PRODUTOOL WHERE RELACPRODOL.CDPRODARVOL = :CDPRODUTO AND RELACPRODOL.CDMARCA = :CDMARCA AND RELACPRODOL.NRORG = :NRORG AND RELACPRODOL.CDPRODARVOL = PRODUTOOL.CDPRODUTO AND RELACPRODOL.NRORG = PRODUTOOL.NRORG";
                      
        $params = [
            "CDPRODUTO"     => $cdproduto,
            "CDMARCA"       => $cdmarca,
            "NRORG"         => $this->environment->getNrOrg()
        ];
        
        $relacProdOl = self::executaSql($select, $params);
 
        return is_array($relacProdOl) && count($relacProdOl) ? $relacProdOl[0] : false;
        
    }
    
    
    public function retornaQfoProdForn($cdfildestProd, $cdproduto, $cdfornecedDest, $dtautofornDest) {
        
        $select = "SELECT FILIAL.CDFILIAL FROM FILIAL WHERE FILIAL.CDFILIAL = :CDFILDEST AND FILIAL.NRORG = :NRORG AND NOT EXISTS(SELECT QFOPRODFORN.CDPRODUTO FROM QFOPRODFORN, PARASUPRI WHERE PARASUPRI.CDFILIAL = FILIAL.CDFILCENTCMP AND PARASUPRI.NRORG = FILIAL.NRORG AND (QFOPRODFORN.CDPRODUTO = :CDPRODUTO) AND (QFOPRODFORN.CDFORNECED = :CDFORNECED) AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND QFOPRODFORN.IDFORNAUTOR = 'N') OR ((QFOPRODFORN.IDFORNAPROV = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND TO_DATE(:DTAUTOFORN, 'DD/MM/YYYY') > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR (PARASUPRI.IDULTIDTVALQ = 'D' AND TO_DATE(:DTAUTOFORN, 'DD/MM/YYYY') > QFOPRODFORN.DTVALPRFORN)))))";

        $params = [
            "CDFILDEST"     => $cdfildestProd,
            "CDPRODUTO"     => $cdproduto,
            "CDFORNECED"    => $cdfornecedDest,
            "DTAUTOFORN"    => $dtautofornDest,
            "NRORG"         => $this->environment->getNrOrg()
        ];
        
        $qfoProdForn = self::executaSql($select, $params);

        return is_array($qfoProdForn) && count($qfoProdForn) ? true : false;
        
    }
    
    
    public function retornaPrecFornDest($cdfildest, $cdcentcmp, $cdforneced, $cdproduto, $cdmarca, $idmotivpresc, $dtprogentafdest, $conspartfildest) {
        
        if($conspartfildest == 'S') {
            $select = "SELECT VRPRECUNIAP, CDMARCITMAP FROM( SELECT VRPRECUNIAP, CDMARCITMAP FROM ( SELECT ITEMCOLE.VRPRECUNIITM AS VRPRECUNIAP, ITEMCOLE.CDMARCA AS CDMARCITMAP, ITEMCOLE.CDFILIAL, PRODUTO.CDPRODUTO, PRODUTO.CDPRODESTO, PRODUTO.VRFATOCONV, ITEMCOLE.CDFORNECED, ITEMCOLE.VRPRECUNIITM, ITEMCOLE.VRPRECECOITM, ITEMCOLE.VRPRECOITMPI, ITEMCOLE.IDITMLISPREC FROM ITEMCOLE INNER JOIN FILIAL ON ITEMCOLE.CDREGIAO = FILIAL.CDREGIAO INNER JOIN PRODUTO ON ITEMCOLE.CDPRODUTO = PRODUTO.CDPRODUTO WHERE FILIAL.CDFILIAL = :CDFILDEST AND ITEMCOLE.CDFILIAL = :CDCENTCMP AND ITEMCOLE.CDFORNECED = :CDFORNECED AND ITEMCOLE.CDPRODUTO = :CDPRODUTO AND ITEMCOLE.NRORG = :NRORG AND ITEMCOLE.CDMARCA = NVL(:CDMARCA, ITEMCOLE.CDMARCA) AND ITEMCOLE.IDITMLISPREC = CASE SUBSTR(:IDMOTIVPRESC,5,1) WHEN '1' THEN 'S' ELSE ITEMCOLE.IDITMLISPREC END AND (TO_DATE(:DTPROGENTAFDEST, 'DD/MM/YYYY') BETWEEN DTINIVALITM AND DTFINVALITM) AND ITEMCOLE.VRPRECUNIITM > 0) PRODFILCOT INNER JOIN PARASUPRI ON PRODFILCOT.CDFILIAL = PARASUPRI.CDFILIAL LEFT JOIN PRODPREFMED ON PRODFILCOT.CDFILIAL = PRODPREFMED.CDFILIAL AND PRODFILCOT.CDPRODESTO = PRODPREFMED.CDPRODUTO AND PRODFILCOT.CDPRODUTO = PRODPREFMED.CDPRODPREF LEFT JOIN PARTFILI PPM ON PRODFILCOT.CDFILIAL = PPM.CDFILIAL AND PRODFILCOT.CDPRODUTO = PPM.CDPRODUTO AND PRODFILCOT.CDMARCITMAP = PPM.CDMARCA LEFT JOIN PARTFILI PPF ON PRODFILCOT.CDFILIAL = PPF.CDFILIAL AND PRODFILCOT.CDPRODUTO = PPF.CDPRODUTO AND PRODFILCOT.CDFORNECED = PPF.CDFORNECED LEFT JOIN PARTFILI PPMF ON PRODFILCOT.CDFILIAL = PPMF.CDFILIAL AND PRODFILCOT.CDPRODUTO = PPMF.CDPRODUTO AND PRODFILCOT.CDMARCITMAP = PPMF.CDMARCA AND PRODFILCOT.CDFORNECED = PPMF.CDFORNECED ORDER BY /* Estabelecendo prioridades - O primeiro registro retornado será o escolhido */ CASE PRODPREFMED.CDPRODPREF WHEN NULL THEN -1 ELSE -10 END, CASE PPMF.CDTIPPART WHEN '7' THEN -9 WHEN '8' THEN -8 WHEN '9' THEN 1 ELSE 0 END, CASE PPF.CDTIPPART WHEN '4' THEN -9 WHEN '5' THEN -8 WHEN '6' THEN 1 ELSE 0 END, CASE PPM.CDTIPPART WHEN '1' THEN -9 WHEN '2' THEN -8 WHEN '3' THEN 1 ELSE 0 END, CASE PPF.CDTIPPART WHEN '4' THEN CASE PARASUPRI.IDTIPOAPUR WHEN NULL THEN PRODFILCOT.VRPRECUNIITM WHEN '1' THEN PRODFILCOT.VRPRECECOITM ELSE PRODFILCOT.VRPRECOITMPI END / PRODFILCOT.VRFATOCONV ELSE CASE PRODFILCOT.IDITMLISPREC WHEN 'S' THEN -6 ELSE -5 END END, CASE PARASUPRI.IDTIPOAPUR WHEN NULL THEN PRODFILCOT.VRPRECUNIITM WHEN '1' THEN PRODFILCOT.VRPRECECOITM ELSE PRODFILCOT.VRPRECOITMPI END / PRODFILCOT.VRFATOCONV) WHERE ROWNUM = 1";
        } else {
            $select = "SELECT VRPRECUNIAP, CDMARCITMAP FROM(SELECT ITEMCOLE.VRPRECUNIITM AS VRPRECUNIAP, ITEMCOLE.CDMARCA AS CDMARCITMAP FROM ITEMCOLE INNER JOIN FILIAL ON ITEMCOLE.CDREGIAO = FILIAL.CDREGIAO INNER JOIN PRODUTO ON ITEMCOLE.CDPRODUTO = PRODUTO.CDPRODUTO INNER JOIN PARASUPRI ON ITEMCOLE.CDFILIAL = PARASUPRI.CDFILIAL LEFT JOIN PRODPREFMED ON ITEMCOLE.CDFILIAL = PRODPREFMED.CDFILIAL AND PRODUTO.CDPRODESTO = PRODPREFMED.CDPRODUTO AND PRODUTO.CDPRODUTO = PRODPREFMED.CDPRODPREF WHERE FILIAL.CDFILIAL = :CDFILDEST AND ITEMCOLE.CDFILIAL = :CDCENTCMP AND ITEMCOLE.CDFORNECED = :CDFORNECED AND ITEMCOLE.CDPRODUTO = :CDPRODUTO AND ITEMCOLE.NRORG = :NRORG AND ITEMCOLE.CDMARCA = NVL(:CDMARCA, ITEMCOLE.CDMARCA) AND ITEMCOLE.IDITMLISPREC = CASE SUBSTR(:IDMOTIVPRESC,5,1) WHEN '1' THEN 'S' ELSE ITEMCOLE.IDITMLISPREC END AND (TO_DATE(:DTPROGENTAFDEST, 'DD/MM/YYYY') BETWEEN DTINIVALITM AND DTFINVALITM) AND ITEMCOLE.VRPRECUNIITM > 0 ORDER BY /* Estabelecendo prioridades - O primeiro registro retornado será o escolhido */ CASE PRODPREFMED.CDPRODPREF WHEN NULL THEN -1 ELSE -10 END, CASE PARASUPRI.IDTIPOAPUR WHEN NULL THEN ITEMCOLE.VRPRECUNIITM WHEN '1' THEN ITEMCOLE.VRPRECECOITM ELSE ITEMCOLE.VRPRECOITMPI END / PRODUTO.VRFATOCONV) WHERE ROWNUM = 1";
        }

        $params = [
            "CDFILDEST"         => $cdfildest,
            "CDCENTCMP"         => $cdcentcmp,
            "CDFORNECED"        => $cdforneced,
            "CDPRODUTO"         => $cdproduto,
            "CDMARCA"           => $cdmarca,
            "IDMOTIVPRESC"      => $idmotivpresc,
            "DTPROGENTAFDEST"   => $dtprogentafdest,
            "NRORG"             => $this->environment->getNrOrg()
        ];
        
        $precFornDest = self::executaSql($select, $params);

        return is_array($precFornDest) && count($precFornDest) ? $precFornDest[0] : false;
        
    }
    
    
    public function retornaProdForn($cdproduto, $cdforneced) {
        
        $select = "SELECT CDPRODUTO FROM PRODFORNCOMP WHERE CDPRODCOMPL = :CDPRODUTO AND CDFORNECED = :CDFORNECED AND NRORG = :NRORG";

        $params = [
            "CDPRODUTO"  => $cdproduto,
            "CDFORNECED" => $cdforneced,
            "NRORG"      => $this->environment->getNrOrg()
        ];
        
        $prodForn = self::executaSql($select, $params);

        return is_array($prodForn) && count($prodForn) ? true : false;
        
    }
    
    
    public function retornaParamProdSup($cdfiliopelog, $cdfildest, $cdproduto) {
        
        $select = "SELECT CDPRODUTO FROM PARAMPRODSUP WHERE CDFILIOPELOG = :CDFILIOPELOG AND CDFILIAL = :CDFILDEST AND CDPRODUTO = :CDPRODUTO AND NRORG = :NRORG";
        
        $params = [
            "CDFILIOPELOG"  => $cdfiliopelog,
            "CDFILDEST"     => $cdfildest,
            "CDPRODUTO"     => $cdproduto,
            "NRORG"         => $this->environment->getNrOrg()
        ];
        
        $prodForn = self::executaSql($select, $params);
        
        return is_array($prodForn) && count($prodForn) ? true : false;
        
    }
    
    
    public function retornaAfsApuracao($cdfillanc, $nrseqapuraf) {
        
        $select = "SELECT AUTOFORNE.DTAUTOFORN, AUTOFORNE.NRSEQAPURAF, AUTOFORNE.NRORG, AUTOFORNE.CDFILDEST, AUTOFORNE.CDFILLANC, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMFANTFORN, FORNECEDOR.CDFORNECED, ITEMAUTF.DTPROGENTAF, AUTOFORNE.NRAUTOFORN, NVL(MINFORNREG.QTMINFORNREG,FORNECEDOR.QTMINAUTFOT) AS QTMINAUTFOT, DECODE(MINFORNREG.QTMINFORNREG,NULL,'F','R') AS IDQTMINFORN, FORNECEDOR.SGUNIDADE, AUTOFORNE.VRTOTALAF, NVL(MINFORNREG.VRMINFORNREG,FORNECEDOR.VRMINAUTFOR) AS VRMINAUTFOR, DECODE(MINFORNREG.VRMINFORNREG,NULL,'F','R') AS IDVRMINFORN, AUTOFORNE.IDSITUATUAAF, AUTOFORNE.IDAFFORALIM, AUTOFORNE.DSINCONSAF, AUTOFORNE.CDOPERADOR, FORNECEDOR.IDGERAFDTENT, SUM(ITEMAUTF.QTPROGENTAF) AS QTTOTALAF, AUTOFORNE.IDBAIXAAF, MIN(ITEMAUTF.DTENTRITMSOL) AS DTENTRITMSOL, AUTOFORNE.IDAFOPERLOG, TO_CHAR(ITEMAUTF.DTPROGENTAF,'DD/MM/YYYY') DTPROGENTAFFILTRO, MIN(TO_NUMBER(PRODFORNCOMP.NRDIASVALPRFORN)) MIN_PRODVALIDADE FROM FORNECEDOR,( SELECT FILIAL.NRORG, FILIAL.CDREGIAO, AUTOFORNE.CDFILDEST, AUTOFORNE.CDFILLANC, AUTOFORNE.NRAUTOFORN, AUTOFORNE.VRTOTALAF, AUTOFORNE.IDSITUATUAAF, AUTOFORNE.DSINCONSAF, AUTOFORNE.CDOPERADOR, AUTOFORNE.CDFORNECED, AUTOFORNE.IDAFOPERLOG, AUTOFORNE.IDBAIXAAF, AUTOFORNE.IDAFPRODWEB, AUTOFORNE.DTAUTOFORN, AUTOFORNE.NRSEQAPURAF, AUTOFORNE.IDAFFORALIM FROM AUTOFORNE, FILIAL WHERE AUTOFORNE.CDFILDEST = FILIAL.CDFILIAL ) AUTOFORNE, ITEMAUTF, MINFORNREG, PRODFORNCOMP WHERE AUTOFORNE.CDFILLANC =:P_CDFILLANC AND AUTOFORNE.NRSEQAPURAF =:P_NRSEQAPURAF AND AUTOFORNE.NRORG = :NRORG AND AUTOFORNE.CDREGIAO = MINFORNREG.CDREGIAO (+) AND AUTOFORNE.CDFORNECED = MINFORNREG.CDFORNECED (+) AND AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN AND AUTOFORNE.CDFORNECED = FORNECEDOR.CDFORNECED AND PRODFORNCOMP.CDFORNECED = AUTOFORNE.CDFORNECED AND PRODFORNCOMP.CDPRODCOMPL = ITEMAUTF.CDPRODUTO AND NVL(AUTOFORNE.IDAFOPERLOG,'2') = '2' AND NVL(AUTOFORNE.IDAFPRODWEB,'N') = 'N' GROUP BY AUTOFORNE.CDFILDEST, AUTOFORNE.DTAUTOFORN, AUTOFORNE.NRSEQAPURAF, AUTOFORNE.NRORG, AUTOFORNE.CDFILLANC, FORNECEDOR.IDTPIJURFORN, FORNECEDOR.NRINSJURFORN, FORNECEDOR.NMFANTFORN, FORNECEDOR.CDFORNECED, ITEMAUTF.DTPROGENTAF, AUTOFORNE.NRAUTOFORN, NVL(MINFORNREG.QTMINFORNREG,FORNECEDOR.QTMINAUTFOT), DECODE(MINFORNREG.QTMINFORNREG,NULL,'F','R'), FORNECEDOR.SGUNIDADE, AUTOFORNE.VRTOTALAF, NVL(MINFORNREG.VRMINFORNREG,FORNECEDOR.VRMINAUTFOR), DECODE(MINFORNREG.VRMINFORNREG,NULL,'F','R'), AUTOFORNE.IDSITUATUAAF, AUTOFORNE.IDAFFORALIM, AUTOFORNE.DSINCONSAF, AUTOFORNE.CDOPERADOR, FORNECEDOR.IDGERAFDTENT, AUTOFORNE.IDBAIXAAF, AUTOFORNE.IDAFOPERLOG";
        
        $params = [
            "P_CDFILLANC"   => $cdfillanc,
            "P_NRSEQAPURAF" => $nrseqapuraf,
            "NRORG"         => $this->environment->getNrOrg()
        ];
        
        $afs = self::executaSql($select, $params);
        
        return is_array($afs) && count($afs) ? $afs : false;
        
    }
    
    
    public function retornaDadosEmail($nrseqapuraf, $cdfilcentcmp, $dtiniapuprec, $dtfinapuprec)
    {
        $select = "SELECT DISTINCT APURPRECO.CDFILCENTCMP, APURPRECO.NRAPURPREC, APURPRECO.DTINIAPUPREC,
                          APURPRECO.DTFINAPUPREC, AUTOFORNE.CDFILDEST, AUTOFORNE.CDFILLANC, 
                          E.IDTPIJURFORN, E.NRINSJURFORN, E.CDFORNECED, E.NMFANTFORN, E.IDUTILZIPAF,
                          NVL(E.IDTPENVAFNORMAL, 'E') IDTPENVAFNORMAL, E.IDTPENVAFFOR, 
                          E.CDFORNERELACAF AS CDFORNERELAC, ITMAPURPREC.CDFORNITMAP, E.DSMAILCOTCOP, 
                          NVL((SELECT DSEMAILFORN FROM TABLE(DADOS_FORN_EMAIL (E.CDFORNECED, 'S', '', :NRORG))), E.DSEMAILCOT) AS DSEMAILCOT
                     FROM ITMAPURPREC INNER JOIN FILIAL 
                                        ON ITMAPURPREC.CDCENTITMAP  = NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) 
                                        AND ITMAPURPREC.NRSEQITMAP   = :P_NRSEQAPURAF 
                                        AND ITMAPURPREC.IDITMSELAPUR = 'S' 
                                        AND FILIAL.CDFILIAL          = :P_CDFILCENTCMP
                                        AND ITMAPURPREC.NRORG        = FILIAL.NRORG
                                      INNER JOIN FORNECEDOR 
                                        ON ITMAPURPREC.CDFORNITMAP = FORNECEDOR.CDFORNECED
                                        AND ITMAPURPREC.NRORG       = FORNECEDOR.NRORG
                                      INNER JOIN FORNECEDOR E
                                        ON NVL(FORNECEDOR.CDFORNERELACAF, FORNECEDOR.CDFORNECED) = E.CDFORNECED
                                        AND FORNECEDOR.NRORG = E.NRORG
                                      INNER JOIN APURPRECO
                                        ON ITMAPURPREC.CDCENTITMAP = APURPRECO.CDFILCENTCMP
                                        AND ITMAPURPREC.NRSEQITMAP = APURPRECO.NRAPURPREC
                                        AND ITMAPURPREC.NRORG = APURPRECO.NRORG
                                        AND APURPRECO.DTINIAPUPREC = :P_DTINIAPUPREC
                                        AND APURPRECO.DTFINAPUPREC = :P_DTFINAPUPREC
                                      INNER JOIN AUTOFORNE
                                        ON ITMAPURPREC.CDFILIAP = AUTOFORNE.CDFILDEST
                                        AND ITMAPURPREC.NRSEQITMAP  = AUTOFORNE.NRSEQAPURAF
                                        AND ITMAPURPREC.CDFORNITMAP = AUTOFORNE.CDFORNECED
                                        AND ITMAPURPREC.NRORG = AUTOFORNE.NRORG
                                      INNER JOIN FILIAL F 
                                        ON AUTOFORNE.CDFILDEST = F.CDFILIAL 
                                        AND AUTOFORNE.NRORG = F.NRORG
                    WHERE NOT EXISTS (SELECT 1
                                        FROM ENVIOAFFORN
                                       WHERE CDFORNECED  = E.CDFORNECED
                                         AND LISTNRSEQAPUR = ITMAPURPREC.NRSEQITMAP
                                         AND DSARQENVIOAF IS NULL
                                         AND IDCONCENVIOAF = 'S')
                      AND ITMAPURPREC.NRORG = :NRORG
                    ORDER BY E.CDFORNECED";
        
        $params = [
            "P_NRSEQAPURAF"  => $nrseqapuraf,
            "P_CDFILCENTCMP" => $cdfilcentcmp,
            "P_DTINIAPUPREC" => $dtiniapuprec,
            "P_DTFINAPUPREC" => $dtfinapuprec,
            "NRORG"          => $this->environment->getNrOrg()
        ];
        
        $dadosEmail = self::executaSql($select, $params);
        
        return $dadosEmail;
        
    }
    
    public function retornaDadosAF($nrseqapuraf, $cdfilcentcmp, $dtiniapuprec, $dtfinapuprec) {
        
        $select = "SELECT AUTOFORNE.CDFILDEST, AUTOFORNE.CDFILLANC, AUTOFORNE.NRAUTOFORN, E.CDFORNECED, ITMAPURPREC.CDFORNITMAP
                     FROM ITMAPURPREC INNER JOIN FORNECEDOR ON ITMAPURPREC.CDFORNITMAP = FORNECEDOR.CDFORNECED AND ITMAPURPREC.NRORG = FORNECEDOR.NRORG 
                                      INNER JOIN FORNECEDOR E ON NVL(FORNECEDOR.CDFORNERELACAF, FORNECEDOR.CDFORNECED) = E.CDFORNECED AND FORNECEDOR.NRORG = E.NRORG 
                                      INNER JOIN APURPRECO ON ITMAPURPREC.CDCENTITMAP = APURPRECO.CDFILCENTCMP AND ITMAPURPREC.NRSEQITMAP = APURPRECO.NRAPURPREC AND ITMAPURPREC.NRORG = APURPRECO.NRORG 
                                      INNER JOIN AUTOFORNE ON ITMAPURPREC.CDFILIAP = AUTOFORNE.CDFILDEST AND ITMAPURPREC.NRSEQITMAP = AUTOFORNE.NRSEQAPURAF AND ITMAPURPREC.CDFORNITMAP = AUTOFORNE.CDFORNECED AND ITMAPURPREC.NRORG = AUTOFORNE.NRORG 
                    WHERE ITMAPURPREC.NRORG = :NRORG 
                      AND ITMAPURPREC.CDCENTITMAP = :P_CDFILCENTCMP 
                      AND ITMAPURPREC.NRSEQITMAP = :P_NRSEQAPURAF 
                      AND ITMAPURPREC.IDITMSELAPUR = 'S' 
                      AND APURPRECO.DTINIAPUPREC = :P_DTINIAPUPREC 
                      AND APURPRECO.DTFINAPUPREC = :P_DTFINAPUPREC 
                    GROUP BY AUTOFORNE.CDFILDEST, AUTOFORNE.CDFILLANC, AUTOFORNE.NRAUTOFORN, E.CDFORNECED, ITMAPURPREC.CDFORNITMAP 
                    ORDER BY E.CDFORNECED";
        
        $params = [
            "P_NRSEQAPURAF"  => $nrseqapuraf,
            "P_CDFILCENTCMP" => $cdfilcentcmp,
            "P_DTINIAPUPREC" => $dtiniapuprec,
            "P_DTFINAPUPREC" => $dtfinapuprec,
            "NRORG"          => $this->environment->getNrOrg()
        ];
        
        $dadosAF = self::executaSql($select, $params);
        
        return $dadosAF;
        
    }
    
    public function retornaDadosEmailOperadorLogado() {
        
        $select = "SELECT OP.CDOPERADOR, OP.DSEMAILOPER, OP.NMOPERADOR, OP.CDSENEMAILOP FROM OPERADOR OP WHERE OP.CDOPERADOR = :P_CDOPERADOR AND OP.NRORG = :NRORG";
        
        $params = [
            "P_CDOPERADOR"   => $this->environment->getCdOperador(),
            "NRORG"          => $this->environment->getNrOrg()
        ];
        
        $dadosEmail = self::executaSql($select, $params);
        
        return is_array($dadosEmail) && count($dadosEmail) ? $dadosEmail[0] : false;
        
    }
    
    
    public function retornaDataEntregaMinimaItemautf($cdfillanc, $cdfildest, $nrautoforn) {
        
        $select = "SELECT MIN(ITEMAUTF.DTPROGENTAF) DTPROGENTAF FROM ITEMAUTF WHERE ITEMAUTF.CDFILLANC = :CDFILLANC AND ITEMAUTF.CDFILDEST = :CDFILDEST AND ITEMAUTF.NRAUTOFORN = :NRAUTOFORN AND ITEMAUTF.NRORG = :NRORG";
        
        $params = [
            "CDFILLANC"  => $cdfillanc,
            "CDFILDEST"  => $cdfildest,
            "NRAUTOFORN" => $nrautoforn,
            "NRORG"      => $this->environment->getNrOrg()
        ];
        
        $dtprogentaf = self::executaSql($select, $params);
        
        return is_array($dtprogentaf) && count($dtprogentaf) ? $dtprogentaf[0]['DTPROGENTAF'] : false;
        
    }
    

    public function atualizaQtItemAutf($itemautf, $qtprogentaf, $idtipolanitm) {
        $itemautf->setQtprogentaf($qtprogentaf);
        $itemautf->setIdtipolanitm($idtipolanitm);
        
        $itemautf->setDtultatu(new \DateTime());
        $itemautf->setNrorgultatu($this->environment->getNrOrg());
        $itemautf->setCdoperultatu($this->environment->getCdoperador());
        
        $this->entityManager->persist($itemautf);
        
        return true;
    }
    
    
    public function atualizaQtItemAutfRemanejo($qtprogentaf, $cdfildest, $cdfillanc, $nrautoforn, $cdproduto, $cdmarca, $dtprogentaf) {
        
        $update = "UPDATE ITEMAUTF SET QTPROGENTAF = QTPROGENTAF + :QTPROGENTAF, DTULTATU = TO_DATE(:DTULTATU, 'DD/MM/YYYY'), CDOPERULTATU = :CDOPERULTATU, NRORGULTATU = :NRORGULTATU WHERE CDFILDEST = :CDFILDEST AND CDFILLANC = :CDFILLANC AND NRAUTOFORN = :NRAUTOFORN AND CDPRODUTO = :CDPRODUTO AND CDMARCA = :CDMARCA AND DTPROGENTAF = TO_DATE(:DTPROGENTAF, 'DD/MM/YYYY') AND NRORG = :NRORG";
        
        $dtatual = new \DateTime();
        
        $params = [
            "QTPROGENTAF" =>  $qtprogentaf,
            "CDFILDEST" => $cdfildest,
            "CDFILLANC" => $cdfillanc,
            "NRAUTOFORN" => $nrautoforn,
            "CDPRODUTO" => $cdproduto,
            "CDMARCA" => $cdmarca,
            "DTPROGENTAF" => $dtprogentaf,
            "NRORG" => $this->environment->getNrOrg(),
            "DTULTATU" => $dtatual->format('d/m/Y'),
            "CDOPERULTATU" => $this->environment->getCdoperador(),
            "NRORGULTATU" => $this->environment->getNrOrg()
        ];
        
        self::executaSql($update, $params, false);
        
        return true;
        
    }
    
    
    public function atualizaAutoforneApuracao($nrseqapuraf, $cdfildest, $cdfillanc, $nrautoforn) {
        
        $update = "UPDATE AUTOFORNE SET NRSEQAPURAF = :NRSEQAPURAF, DTULTATU = SYSDATE, CDOPERULTATU = :CDOPERULTATU, NRORGULTATU = :NRORGULTATU WHERE CDFILDEST = :CDFILDEST AND CDFILLANC = :CDFILLANC AND NRAUTOFORN = :NRAUTOFORN AND AUTOFORNE.IDSITUATUAAF IS NULL AND NVL(AUTOFORNE.IDAFFORALIM, 'N') = 'N' AND NRORG = :NRORG";
        
        $params = [
            "NRSEQAPURAF" => $nrseqapuraf,
            "CDFILDEST" => $cdfildest,
            "CDFILLANC" => $cdfillanc,
            "NRAUTOFORN" => $nrautoforn,
            "NRORG" => $this->environment->getNrOrg(),
            "CDOPERULTATU" => $this->environment->getCdoperador(),
            "NRORGULTATU" => $this->environment->getNrOrg()
        ];
        
        self::executaSql($update, $params, false);
        
        return true;
        
    }
    
    
    public function atualizaAutoforneApuracaoTodas($seqapurnovo, $cdfillanc, $nrseqapuraf) {
        
        $update = "UPDATE AUTOFORNE SET NRSEQAPURAF = :SEQAPURNOVO, DTULTATU = SYSDATE, CDOPERULTATU = :CDOPERULTATU, NRORGULTATU = :NRORGULTATU WHERE AUTOFORNE.IDSITUATUAAF IS NULL AND NVL(AUTOFORNE.IDAFFORALIM, 'N') = 'N' AND AUTOFORNE.CDFILLANC = :CDFILLANC AND AUTOFORNE.NRSEQAPURAF = :NRSEQAPURAF AND AUTOFORNE.NRORG = :NRORG";

        $params = [
            "SEQAPURNOVO" => $seqapurnovo,
            "CDFILLANC" => $cdfillanc,
            "NRSEQAPURAF" => $nrseqapuraf,
            "NRORG" => $this->environment->getNrOrg(),
            "CDOPERULTATU" => $this->environment->getCdoperador(),
            "NRORGULTATU" => $this->environment->getNrOrg()
        ];
        
        self::executaSql($update, $params, false);
        
        return true;
        
    }
    
    
    public function concluirApuracaoPreco($tipo, $cdfilcentcmp, $nrseqapuraf) {
        
        $update = "UPDATE APURPRECO SET IDSITAPUPREC = :TIPO, DTCONAPUPREC = SYSDATE, DTULTATU = SYSDATE, CDOPERULTATU = :CDOPERULTATU, NRORGULTATU = :NRORGULTATU WHERE NRAPURPREC = :NRSEQAPURAF AND CDFILCENTCMP = :CDFILCENTCMP AND NRORG = :NRORG";

        $params = [
            "TIPO" => $tipo,
            "CDFILCENTCMP" => $cdfilcentcmp,
            "NRSEQAPURAF" => $nrseqapuraf,
            "NRORG" => $this->environment->getNrOrg(),
            "CDOPERULTATU" => $this->environment->getCdoperador(),
            "NRORGULTATU" => $this->environment->getNrOrg()
        ];
        
        self::executaSql($update, $params, false);
        
        return true;
        
    }
    
    
    public function concluirNormal($nrseqapuraf, $cdfillanc) {
        
        $update = "UPDATE AUTOFORNE SET IDBAIXAAF = NULL, DTULTATU = SYSDATE, CDOPERULTATU = :CDOPERULTATU, NRORGULTATU = :NRORGULTATU WHERE NRSEQAPURAF = :NRSEQAPURAF AND CDFILLANC = :CDFILLANC AND NRORG = :NRORG AND EXISTS(SELECT 1 FROM FORNECEDOR F WHERE F.CDFORNECED = AUTOFORNE.CDFORNECED AND NVL(F.IDTPENVAFFOR, '1') <> '2' AND NRORG = :NRORG)";

        $params = [
            "NRSEQAPURAF" => $nrseqapuraf,
            "CDFILLANC" => $cdfillanc,
            "NRORG" => $this->environment->getNrOrg(),
            "CDOPERULTATU" => $this->environment->getCdoperador(),
            "NRORGULTATU" => $this->environment->getNrOrg()
        ];
        
        self::executaSql($update, $params, false);
        
        return true;
        
    }
    
    
    public function concluirEDI($nrseqapuraf, $cdfillanc) {
        
        $update = "UPDATE AUTOFORNE SET IDBAIXAAF = '7', DTULTATU = SYSDATE, CDOPERULTATU = :CDOPERULTATU, NRORGULTATU = :NRORGULTATU WHERE NRSEQAPURAF = :NRSEQAPURAF AND CDFILLANC = :CDFILLANC AND NRORG = :NRORG AND EXISTS(SELECT 1 FROM FORNECEDOR F WHERE AUTOFORNE.CDFORNECED = F.CDFORNECED AND F.IDTPENVAFFOR = '2' AND NRORG = :NRORG)";

        $params = [
            "NRSEQAPURAF" => $nrseqapuraf,
            "CDFILLANC" => $cdfillanc,
            "NRORG" => $this->environment->getNrOrg(),
            "CDOPERULTATU" => $this->environment->getCdoperador(),
            "NRORGULTATU" => $this->environment->getNrOrg()
        ];
        
        self::executaSql($update, $params, false);
        
        return true;
        
    }
    
    
    public function atualizaSeqEnvioAf($nrseqenvioaforn, $cdforneced, $nrapurprec, $nrautoforn, $idEnvioOk) 
    {
        $update = "UPDATE AUTOFORNE 
                      SET NRSEQENVIOAFORN = :NRSEQENVIOAFORN, 
                          DTULTATU = SYSDATE, 
                          CDOPERULTATU = :CDOPERULTATU, 
                          NRORGULTATU = :NRORGULTATU,
                          DTENVIOAF = CASE :P_IDCONCENVIOAF WHEN 'S' THEN SYSDATE ELSE NULL END
                    WHERE AUTOFORNE.CDFORNECED = :CDFORNECED 
                      AND INSTR(:NRAPURPREC, AUTOFORNE.NRSEQAPURAF) > 0 
                      AND AUTOFORNE.NRAUTOFORN = :NRAUTOFORN 
                      AND AUTOFORNE.NRORG = :NRORG";

        $params = [
            "NRSEQENVIOAFORN" => $nrseqenvioaforn,
            "CDFORNECED"      => $cdforneced,
            "NRAPURPREC"      => $nrapurprec,
            "NRAUTOFORN"      => $nrautoforn,
            "P_IDCONCENVIOAF" => $idEnvioOk,
            "NRORG"           => $this->environment->getNrOrg(),
            "CDOPERULTATU"    => $this->environment->getCdoperador(),
            "NRORGULTATU"     => $this->environment->getNrOrg()
        ];
        
        self::executaSql($update, $params, false);
        
        return true;
        
    }
    
    
    public function atualizaEnvioAf($cdforneced, $listnrseqapur, $dtiniapurafforn, $dtfinapurafforn, $idtclassenvafor, $dtentregafforn, $qtafsenviofor, $idconcenvioaf) {
        
        $update = "UPDATE ENVIOAFFORN SET IDTCLASSENVAFOR = NVL(:IDTCLASSENVAFOR, IDTCLASSENVAFOR), DTENTREGAFFORN = NVL(:DTENTREGAFFORN, DTENTREGAFFORN), QTAFSENVIOFOR = NVL(:QTAFSENVIOFOR, QTAFSENVIOFOR), IDCONCENVIOAF = :IDCONCENVIOAF, DTULTATU = SYSDATE, CDOPERULTATU = :CDOPERULTATU, NRORGULTATU = :NRORGULTATU WHERE CDFORNECED = :CDFORNECED AND LISTNRSEQAPUR = :LISTNRSEQAPUR AND DTINIAPURAFFORN = :DTINIAPURAFFORN AND DTFINAPURAFFORN = :DTFINAPURAFFORN AND NRORG = :NRORG";

        $params = [
            "CDFORNECED" => $cdforneced,
            "LISTNRSEQAPUR" => $listnrseqapur,
            "DTINIAPURAFFORN" => $dtiniapurafforn,
            "DTFINAPURAFFORN" => $dtfinapurafforn,
            "IDTCLASSENVAFOR" => $idtclassenvafor,
            "DTENTREGAFFORN" => $dtentregafforn,
            "QTAFSENVIOFOR" => $qtafsenviofor,
            "IDCONCENVIOAF" => $idconcenvioaf,
            "NRORG" => $this->environment->getNrOrg(),
            "CDOPERULTATU" => $this->environment->getCdoperador(),
            "NRORGULTATU" => $this->environment->getNrOrg()
        ];
        
        self::executaSql($update, $params, false);
        
        return true;
        
    }
    
    
    public function deletaAutoforne($cdfildest, $cdfillanc, $nrautoforn) {
        $itensAF = self::retornaListaItemAutfAF($cdfildest, $cdfillanc, $nrautoforn);

        if(!$itensAF) {
            $sql = "DELETE FROM AUTOFORNE WHERE CDFILDEST = :CDFILDEST AND CDFILLANC = :CDFILLANC AND NRAUTOFORN = :NRAUTOFORN AND NRORG = :NRORG";
            
            $params = [
                "CDFILDEST" => $cdfildest,
                "CDFILLANC" => $cdfillanc,
                "NRAUTOFORN" => $nrautoforn,
                "NRORG" => $this->environment->getNrOrg()
            ];
            
            self::executaSql($sql, $params, false);

            return true;
        }
        
        return false;
    }
    
    
    public function deletaItemAutf($cdfildest, $cdfillanc, $nrautoforn, $cdproduto, $dtprogentaf, $cdmarca) {
        
        $sql = "DELETE FROM ITEMAUTF WHERE CDFILDEST = :CDFILDEST AND CDFILLANC = :CDFILLANC AND NRAUTOFORN = :NRAUTOFORN AND CDMARCA = :CDMARCA AND CDPRODUTO = :CDPRODUTO AND DTPROGENTAF = TO_DATE(:DTPROGENTAF, 'DD/MM/YYYY') AND NRORG = :NRORG";
                
        $params = [
            "CDFILDEST" => $cdfildest,
            "CDFILLANC" => $cdfillanc,
            "NRAUTOFORN" => $nrautoforn,
            "CDMARCA" => $cdmarca,
            "CDPRODUTO" => $cdproduto,
            "DTPROGENTAF" => $dtprogentaf,
            "NRORG" => $this->environment->getNrOrg()
        ];
        
        self::executaSql($sql, $params, false);
        
        return true;
    }
    
    
    public function insereItemAutf($dtprogent_old, $dtprogent_nova, $qtprogentaf, $idtipolanitm, $cdfildest, $cdfillanc, $nrautoforn, $cdproduto, $cdmarca) {
        
        $insert = "INSERT INTO ITEMAUTF(CDFILDEST, CDFILLANC, NRAUTOFORN, CDMARCA, CDPRODUTO, DTPROGENTAF, CDFORNECED, CDSEGMARCA, NRPARCITMAF, DTEFETENTAF, QTPROGENTAF, VRPREUNIAF, VRPERDESAF, QTEFETENTRAF, CDEMPRESA, IDTIPEMITMAF, VRPRECECOAF, VRPRECCOTAF, IDBAIXITMAF, NRLANCTONF, TXOBSITMAF, VRDESCITMAF, NRLOTEESTQ, NRSUBLOTE, CDPRODPRODAF, DTENTRITMSOL, DSINCONSITAF, IDMOTPRESCAF, QTVOLUITEMAF, IDTIPOLANITM, CDFILCOTITAF, NRCOTPREITAF, CDMARCOTITAF, CDREGCOTITAF, CDFORCOTITAF, CDPROCOTITAF, NRLISTAITAF, IDTPLANITEAF, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, NRORG, IDATIVO) SELECT CDFILDEST, CDFILLANC, NRAUTOFORN, CDMARCA, CDPRODUTO, TO_DATE(:DTPROGENT_NOVA, 'DD/MM/YYYY'), CDFORNECED, CDSEGMARCA, NRPARCITMAF, DTEFETENTAF, :QTPROGENTAF, VRPREUNIAF, VRPERDESAF, QTEFETENTRAF, CDEMPRESA, IDTIPEMITMAF, VRPRECECOAF, VRPRECCOTAF, IDBAIXITMAF, NRLANCTONF, TXOBSITMAF, VRDESCITMAF, NRLOTEESTQ, NRSUBLOTE, CDPRODPRODAF, DTENTRITMSOL, DSINCONSITAF, IDMOTPRESCAF, QTVOLUITEMAF, :IDTIPOLANITM, CDFILCOTITAF, NRCOTPREITAF, CDMARCOTITAF, CDREGCOTITAF, CDFORCOTITAF, CDPROCOTITAF, NRLISTAITAF, IDTPLANITEAF, TO_DATE(:DTINCLUSAO, 'DD/MM/YYYY'), :CDOPERINCLUSAO, :NRORGINCLUSAO, :NRORG, :IDATIVO FROM ITEMAUTF WHERE NRORG =:NRORG AND CDFILDEST =:CDFILDEST AND CDFILLANC =:CDFILLANC AND NRAUTOFORN =:NRAUTOFORN AND CDPRODUTO =:CDPRODUTO AND CDMARCA =:CDMARCA AND DTPROGENTAF = TO_DATE(:DTPROGENT_OLD, 'DD/MM/YYYY') AND NOT EXISTS( SELECT 1 FROM ITEMAUTF I WHERE CDFILDEST =:CDFILDEST AND CDFILLANC =:CDFILLANC AND NRAUTOFORN =:NRAUTOFORN AND CDPRODUTO =:CDPRODUTO AND CDMARCA =:CDMARCA AND DTPROGENTAF = TO_DATE(:DTPROGENT_NOVA, 'DD/MM/YYYY'))";
        
        $dtatual = new \DateTime();
        
        $params = [
            'DTPROGENT_OLD' => $dtprogent_old,
            'DTPROGENT_NOVA' => $dtprogent_nova,
            'QTPROGENTAF' => $qtprogentaf,
            'IDTIPOLANITM' => $idtipolanitm,
            'CDFILDEST' => $cdfildest,
            'CDFILLANC' => $cdfillanc,
            'NRAUTOFORN' => $nrautoforn,
            'CDPRODUTO' => $cdproduto,
            'CDMARCA' => $cdmarca,
            'DTINCLUSAO' => $dtatual->format('d/m/Y'),
            'CDOPERINCLUSAO' => $this->environment->getCdoperador(),
            'NRORGINCLUSAO' => $this->environment->getNrOrg(),
            'NRORG' => $this->environment->getNrOrg(),
            'IDATIVO' => self::ATIVO
        ];
        
        self::executaSql($insert, $params, false);
        
        return true;
    }
    
    
    public function insereItemAutfRemanejo($cdfildest, $cdfillanc, $nrautoforndest, $cdmarcadest, $dtprogentafdest, $cdproduto, $vrpreuniaf, $dtentritmsol, $nrautofornorig, $dtprogentaforig, $cdprodorig, $cdmarca) {
        
        $insert = "INSERT INTO ITEMAUTF(CDFILDEST, CDFILLANC, NRAUTOFORN, CDMARCA, CDPRODUTO, DTPROGENTAF, CDSEGMARCA, NRPARCITMAF, QTPROGENTAF, VRPREUNIAF, VRPERDESAF, VRDESCITMAF, TXOBSITMAF, DTENTRITMSOL, IDTPLANITEAF, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, NRORG, IDATIVO) SELECT :CDFILDEST, :CDFILLANC, :NRAUTOFORNDEST, :CDMARCADEST, :CDPRODUTO, TO_DATE(:DTPROGENTAFDEST, 'DD/MM/YYYY'), CDSEGMARCA, '00', QTPROGENTAF, :VRPREUNIAF, VRPERDESAF, VRDESCITMAF, TXOBSITMAF, NVL(TO_DATE(:DTENTRITMSOL, 'DD/MM/YYYY'), DTENTRITMSOL), IDTPLANITEAF, TO_DATE(:DTINCLUSAO, 'DD/MM/YYYY'), :CDOPERINCLUSAO, :NRORGINCLUSAO, :NRORG, :IDATIVO FROM ITEMAUTF WHERE CDFILDEST = :CDFILDEST AND CDFILLANC = :CDFILLANC AND NRAUTOFORN = :NRAUTOFORNORIG AND CDPRODUTO = :CDPRODORIG AND CDMARCA = :CDMARCA AND DTPROGENTAF = TO_DATE(:DTPROGENTAFORIG, 'DD/MM/YYYY') AND NRORG = :NRORG";
        
        $dtatual = new \DateTime();
        
        $params = [
            'CDFILDEST' => $cdfildest,
            'CDFILLANC' => $cdfillanc,
            'NRAUTOFORNDEST' => $nrautoforndest,
            'CDMARCADEST' => $cdmarcadest,
            'DTPROGENTAFDEST' => $dtprogentafdest,
            'CDPRODUTO' => $cdproduto,
            'VRPREUNIAF' => $vrpreuniaf,
            'DTENTRITMSOL' => $dtentritmsol,
            'NRAUTOFORNORIG' => $nrautofornorig,
            'DTPROGENTAFORIG' => $dtprogentaforig,
            'CDPRODORIG' => $cdprodorig,
            'CDMARCA' => $cdmarca,
            'DTINCLUSAO' => $dtatual->format('d/m/Y'),
            'CDOPERINCLUSAO' => $this->environment->getCdoperador(),
            'NRORGINCLUSAO' => $this->environment->getNrOrg(),
            'NRORG' => $this->environment->getNrOrg(),
            'IDATIVO' => self::ATIVO
        ];
        
        self::executaSql($insert, $params, false);
        
        return true;
    }
    
    
    public function insereMovopaf(array $params) {
        
        $insert = "INSERT INTO MOVOPAF( CDFILDESMOV, CDFILLANMOV, NRAUTOMOV, CDPRODMOV, CDMARCMOV, DTPROGENTMOV, DTOPERAF, CDOPERADOR, DSALTERAF, DSJUSTOPERMOV, IDOPERAMOVAF, IDUTATUALIZASOL, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, NRORG, IDATIVO) VALUES ( :CDFILDESMOV, :CDFILLANMOV, :NRAUTOMOV, :CDPRODMOV, :CDMARCMOV, TO_DATE(:DTPROGENTMOV, 'DD/MM/YYYY'), TO_DATE(:DTOPERAF, 'DD/MM/YYYY'), :CDOPERADOR, :DSALTERAF, :DSJUSTOPERMOV, :IDOPERAMOVAF, :IDUTATUALIZASOL, TO_DATE(:DTINCLUSAO, 'DD/MM/YYYY'), :CDOPERINCLUSAO, :NRORGINCLUSAO, :NRORG, :IDATIVO)";
        
        $dtatual = new \DateTime();
        
        $params = [
            'CDFILDESMOV' => $params['CDFILDEST'],
            'CDFILLANMOV' => $params['CDFILLANC'],
            'NRAUTOMOV' => $params['NRAUTOFORN'],
            'CDPRODMOV' => $params['CDPRODUTO'],
            'CDMARCMOV' => $params['CDMARCA'],
            'DTPROGENTMOV' => $params['DTPROGENTAF'],
            'DTOPERAF' => $dtatual->format('d/m/Y'),
            'CDOPERADOR' => $this->environment->getCdoperador(),
            'DSALTERAF' => $params['DSALTERAF'],
            'DSJUSTOPERMOV' => $params['DSJUSTOPERMOV'],
            'IDOPERAMOVAF' => $params['IDOPERAMOVAF'],
            'IDUTATUALIZASOL' => $params['IDUTATUALIZASOL'],
            'DTINCLUSAO' => $dtatual->format('d/m/Y'),
            'CDOPERINCLUSAO' => $this->environment->getCdoperador(), 
            'NRORGINCLUSAO' => $this->environment->getNrOrg(), 
            'NRORG' => $this->environment->getNrOrg(), 
            'IDATIVO' => self::ATIVO
        ];
        
        self::executaSql($insert, $params, false);
        
        return true;
    }
    
    
    public function insereApuracao($nrseqapurnova, $nrapurprec, $cdfilcentcmp) {
        
        $insert = "INSERT INTO APURPRECO(CDFILCENTCMP, NRAPURPREC, CDCOMPRADOR, DTINIAPUPREC, DTFINAPUPREC, IDSITAPUPREC, DTAPURPREC, CDOPERADOR, CDFILLANC, NRAPURORIG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, NRORG, IDATIVO) SELECT A.CDFILCENTCMP, :NRSEQAPURNOVA, A.CDCOMPRADOR, A.DTINIAPUPREC, A.DTFINAPUPREC, '1', SYSDATE, :CDOPERADOR, A.CDFILLANC, :NRAPURPREC, SYSDATE, :CDOPERINCLUSAO, :NRORGINCLUSAO, :NRORG, :IDATIVO FROM APURPRECO A WHERE A.CDFILCENTCMP = :CDFILCENTCMP AND A.NRAPURPREC = :NRAPURPREC AND A.NRORG = :NRORG";
        
        $params = [
            'NRSEQAPURNOVA' => $nrseqapurnova,
            'CDOPERADOR' => $this->environment->getCdoperador(),
            'NRAPURPREC' => $nrapurprec,
            'CDFILCENTCMP' => $cdfilcentcmp,
            'CDOPERINCLUSAO' => $this->environment->getCdoperador(),
            'NRORGINCLUSAO' => $this->environment->getNrOrg(),
            'NRORG' => $this->environment->getNrOrg(),
            'IDATIVO' => self::ATIVO
        ];
        
        self::executaSql($insert, $params, false);
        
        return true;
    }
    
    
    public function insereItemApuracao($nrseqapurnova, $nrapurprec, $cdfilcentcmp) {
        
        $insert = "INSERT INTO ITMAPURPREC(CDCENTITMAP, NRSEQITMAP, CDREGITMAP, CDFORNITMAP, NRCOLEITMAP, DTENTRAPUT, CDFILIAP, CDPRODITMAP, CDMARCITMAP, IDITMSELAPUR, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, NRORG, IDATIVO) SELECT ITM.CDCENTITMAP, :NRSEQAPURNOVA, ITM.CDREGITMAP, CDFORNITMAP, ITM.NRCOLEITMAP, SYSDATE, ITM.CDFILIAP, ITM.CDPRODITMAP, ITM.CDMARCITMAP, ITM.IDITMSELAPUR, SYSDATE, :CDOPERINCLUSAO, :NRORGINCLUSAO, :NRORG, :IDATIVO FROM ( SELECT MAX(CDCENTITMAP) AS CDCENTITMAP, MAX(CDREGITMAP) AS CDREGITMAP, CDFORNITMAP, MAX(NRCOLEITMAP) AS NRCOLEITMAP, CDFILIAP, MAX(CDPRODITMAP) AS CDPRODITMAP, MAX(CDMARCITMAP) AS CDMARCITMAP, MAX(IDITMSELAPUR) AS IDITMSELAPUR FROM ITMAPURPREC I WHERE I.CDCENTITMAP = :CDFILCENTCMP AND I.NRSEQITMAP = :NRAPURPREC AND I.NRORG = :NRORG AND I.IDITMSELAPUR = 'S' GROUP BY CDFORNITMAP, CDFILIAP) ITM";
        
        $params = [
            'NRSEQAPURNOVA' => $nrseqapurnova,
            'NRAPURPREC' => $nrapurprec,
            'CDFILCENTCMP' => $cdfilcentcmp,
            'CDOPERINCLUSAO' => $this->environment->getCdoperador(),
            'NRORGINCLUSAO' => $this->environment->getNrOrg(),
            'NRORG' => $this->environment->getNrOrg(),
            'IDATIVO' => self::ATIVO
        ];
        
        self::executaSql($insert, $params, false);
        
        return true;
    }
    
    public function insereEnviaAf($nrseqenvioaforn, $cdforneced, $dsarqenvioaf, $nrapurprec, $dtiniapuprec, $dtfinapuprec, $qtafsenviofor, $idutilsmtp, $dsextensao, $idconcenvioaf) {
        $insert = "INSERT INTO ENVIOAFFORN ( NRSEQENVIOAFORN, CDFORNECED, CDPAIS, SGESTADO, DTINIAPURAFFORN, DTFINAPURAFFORN, DTENVIOAFFORN, QTAFSENVIOFOR, QTAFSNENVFOR, IDTIPENVLIDO, IDTIPENVAFFORN, DSARQENVIOAF, DTENTREGAFFORN, LISTNRSEQAPUR, IDUTILSMTP, DSEXTENSAO, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, NRORG, IDATIVO, IDCONCENVIOAF, IDTCLASSENVAFOR ) SELECT :NRSEQENVIOAFORN, F.CDFORNECED, E.CDPAIS, E.SGESTADO, :DTINIAPUPREC, :DTFINAPUPREC, SYSDATE, :QTAFSENVIOFOR, 0, 'N', NVL(F.IDTPENVAFNORMAL, 'E'), :DSARQENVIOAF, SYSDATE, :NRAPURPREC, :IDUTILSMTP, :DSEXTENSAO, SYSDATE, :CDOPERINCLUSAO, :NRORGINCLUSAO, :NRORG, :IDATIVO, :IDCONCENVIOAF, 'N' FROM FORNECEDOR F, ENDEFORN E WHERE F.CDFORNECED = :CDFORNECED AND F.CDFORNECED = E.CDFORNECED AND E.IDTPENDEFORN = 'P' AND F.NRORG = :NRORG AND NOT EXISTS ( SELECT 1 FROM ENVIOAFFORN E WHERE E.CDFORNECED = :CDFORNECED AND E.LISTNRSEQAPUR = :NRAPURPREC AND E.NRORG = :NRORG AND DSARQENVIOAF IS NULL )";
        
        $params = [
            "NRSEQENVIOAFORN" => $nrseqenvioaforn,
            "CDFORNECED" => $cdforneced,
            "DSARQENVIOAF" => $dsarqenvioaf,
            "NRAPURPREC" => $nrapurprec,
            "DTINIAPUPREC" => $dtiniapuprec,
            "DTFINAPUPREC" => $dtfinapuprec,
            "QTAFSENVIOFOR" => $qtafsenviofor,
            "IDUTILSMTP" => $idutilsmtp,
            "DSEXTENSAO" => $dsextensao,
            'CDOPERINCLUSAO' => $this->environment->getCdoperador(),
            'NRORGINCLUSAO' => $this->environment->getNrOrg(),
            'NRORG' => $this->environment->getNrOrg(),
            'IDATIVO' => self::ATIVO,
            'IDCONCENVIOAF' => $idconcenvioaf
        ];
        
        self::executaSql($insert, $params, false);
        
        return true;
    }
    
    
    public function proceCarregaPeriforn($cdfilial, $cdforneced, $dtprogentaf) {
        //without commit in procedure
        $procedure = new StoredProcedure($this->connection, 'CARREGA_PERIFORN');
        
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $cdfilial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFORNECED', Param::PARAM_INPUT, $cdforneced, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTPROGENTAF', Param::PARAM_INPUT, $dtprogentaf, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NEW_DTPROGENTAF', Param::PARAM_OUTPUT,  null, null, 20));
        
        $novaDtprogentaf = $procedure->execute();

        if(is_array($novaDtprogentaf) && count($novaDtprogentaf)) {
            $novaDtprogentaf = $novaDtprogentaf['P_NEW_DTPROGENTAF'];
        }

        return $novaDtprogentaf;
    }
    
    public function getGerentePorComprador($cdompradoraf) {
        $query = "SELECT OPERGERE.CDOPERADOR, OPERGERE.NMOPERADOR FROM OPERADOR OPERGERE, GERECOMP WHERE GERECOMP.CDOPERCOMP = :P_CDCOMPAF AND GERECOMP.CDOPERGERE = OPERGERE.CDOPERADOR AND GERECOMP.NRORG = :P_NRORG ORDER BY OPERGERE.CDOPERADOR";
        
        $params = [
            'P_CDCOMPAF' => $cdompradoraf,
            'P_NRORG' => $this->environment->getNrOrg()
        ];
        
        return self::executaSql($query, $params);
    }
    
    public function qryVdComprador($params) {
        $query = "SELECT COMP.CDOPERADOR, OPER.NMOPERADOR FROM COMPRADOR COMP, OPERADOR OPER WHERE (COMP.CDOPERADOR = OPER.CDOPERADOR) AND (COMP.CDOPERADOR = :P_CDOPERADOR) ORDER BY COMP.CDOPERADOR";
        
        return self::executaSql($query, $params);
    }
    
    public function adqTodasInconsAF($params) {
        $query = "SELECT AUTOFORNE.CDFILDEST, AUTOFORNE.CDFILLANC, AUTOFORNE.NRAUTOFORN, AUTOFORNE.CDOPERADOR FROM APURPRECO, AUTOFORNE WHERE AUTOFORNE.CDFILLANC = APURPRECO.CDFILCENTCMP AND AUTOFORNE.NRSEQAPURAF = APURPRECO.NRAPURPREC AND APURPRECO.IDSITAPUPREC = '1' AND NVL(:P_CDCOMPRADOR, AUTOFORNE.CDOPERADOR) = AUTOFORNE.CDOPERADOR AND (INSTR(:P_NRAPURPREC, APURPRECO.NRAPURPREC) > 0 OR :P_NRAPURPREC = 'T') AND (INSTR(:P_CDFORNECED, AUTOFORNE.CDFORNECED) > 0 OR :P_CDFORNECED = 'T') AND (INSTR(:P_CDFILIAL, AUTOFORNE.CDFILDEST) > 0 OR :P_CDFILIAL = 'T') AND ((AUTOFORNE.IDSITUATUAAF IS NOT NULL) OR (AUTOFORNE.IDAFFORALIM = 'S')) AND (APURPRECO.NRLOGCORTEOL IS NULL)";
        
        return self::executaSql($query, $params);
    }
    
    public function adqListaInconsAF($params) {
        $query = "SELECT AUTOFORNE.CDFILDEST, AUTOFORNE.CDFILLANC, AUTOFORNE.NRAUTOFORN, AUTOFORNE.CDOPERADOR FROM LISTA LISTAAF, AUTOFORNE WHERE LISTAAF.NRLISTA = :P_NRLISTAAF AND SUBSTR(LISTAAF.CDLISTA, 1, 4) = AUTOFORNE.CDFILDEST AND SUBSTR(LISTAAF.CDLISTA, 5, 4) = AUTOFORNE.CDFILLANC AND SUBSTR(LISTAAF.CDLISTA, 9, 10) = AUTOFORNE.NRAUTOFORN AND SUBSTR(LISTAAF.CDLISTA, 19,12) = AUTOFORNE.CDOPERADOR";
        
        return self::executaSql($query, $params);
    }
    
    public function adqParametro($params) {
        $query = "SELECT NVL(PARASUPRI.IDAFCOMPLIMGER, 'N') IDAFCOMPLIMGER, IDINCONSPRECSUP, NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) CDFILCENTCMP FROM PARASUPRI, FILIAL WHERE FILIAL.CDFILIAL = :P_CDFILIAL AND PARASUPRI.CDFILIAL = NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)";
        
        return self::executaSql($query, $params);
    }
    
    public function adqLimiteGeralGerente($params) {
        $query = "SELECT AUTOFORNE.CDFILLANC, AUTOFORNE.CDFILDEST, AUTOFORNE.NRAUTOFORN FROM ( SELECT AUTOFORNE.CDFILDEST, AUTOFORNE.NRAUTOFORN, AUTOFORNE.CDFILLANC, AUTOFORNE.DTAUTOFORN FROM AUTOFORNE, GERENTE WHERE ( AUTOFORNE.CDFILDEST = :P_CDFILDEST ) AND ( AUTOFORNE.CDFILLANC = :P_CDFILLANC ) AND ( AUTOFORNE.NRAUTOFORN = :P_NRAUTOFORN ) AND ( GERENTE.CDOPERADOR = :P_CDGERENTE ) AND ( GERENTE.VRLIMIAFGER IS NULL OR GERENTE.VRLIMIAFGER >= AUTOFORNE.VRTOTALAF ) AND ( GERENTE.VRLIMAFMESG IS NULL OR GERENTE.VRLIMAFMESG >= ( SELECT NVL(SUM(AF_MES.VRTOTALAF), 0) + AUTOFORNE.VRTOTALAF FROM AUTOFORNE AF_MES WHERE AF_MES.CDGERENTE = :P_CDGERENTE AND TO_CHAR(AF_MES.DTAUTOFORN, 'MMYYYY') = TO_CHAR( AUTOFORNE.DTAUTOFORN, 'MMYYYY') ) ) ) AUTOFORNE WHERE NOT EXISTS ( SELECT LIMGERPROD.CDPRODUTO FROM ITEMAUTF, LIMGERPROD, PRODUTO PL, ( SELECT IMPITMAF.CDFILDEST, IMPITMAF.CDFILLANC, IMPITMAF.NRAUTOFORN, IMPITMAF.CDPRODUTO, SUM(IMPITMAF.VRADIMPAF) AS VRIMPOSTO FROM IMPITMAF, AUTOFORNE WHERE AUTOFORNE.CDFILDEST = :P_CDFILDEST AND AUTOFORNE.CDFILLANC = :P_CDFILLANC AND AUTOFORNE.NRAUTOFORN = :P_NRAUTOFORN AND IMPITMAF.CDFILDEST = AUTOFORNE.CDFILDEST AND IMPITMAF.CDFILLANC = AUTOFORNE.CDFILLANC AND IMPITMAF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN GROUP BY IMPITMAF.CDFILDEST, IMPITMAF.CDFILLANC, IMPITMAF.NRAUTOFORN, IMPITMAF.CDPRODUTO ) IMP WHERE ITEMAUTF.CDFILDEST = :P_CDFILDEST AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN AND LIMGERPROD.CDOPERADOR = :P_CDGERENTE AND ITEMAUTF.CDFILDEST = IMP.CDFILDEST (+) AND ITEMAUTF.CDFILLANC = IMP.CDFILLANC (+) AND ITEMAUTF.NRAUTOFORN = IMP.NRAUTOFORN(+) AND ITEMAUTF.CDPRODUTO = IMP.CDPRODUTO (+) AND PL.CDPRODUTO = LIMGERPROD.CDPRODUTO AND PL.CDARVPROD = ( SELECT MAX(PRODUTO.CDARVPROD) FROM LIMGERPROD MAIOR_PROD, PRODUTO, PRODUTO P WHERE MAIOR_PROD.CDOPERADOR = :P_CDGERENTE AND PRODUTO.CDPRODUTO = MAIOR_PROD.CDPRODUTO AND P.CDPRODUTO = ITEMAUTF.CDPRODUTO AND P.CDARVPROD LIKE PRODUTO.CDARVPROD || '%' ) AND ( LIMGERPROD.VRLIMGPRODAF < ( SELECT SUM(ITM_PROD.QTPROGENTAF * ITM_PROD.VRPREUNIAF) - SUM(( ITM_PROD.QTPROGENTAF * ITM_PROD.VRPREUNIAF * NVL( ITM_PROD.VRPERDESAF,0)) / 100) + SUM(NVL(IMPOSTO.VRIMPOSTO, 0)) FROM ITEMAUTF ITM_PROD, ( SELECT IMPITMAF.CDFILDEST, IMPITMAF.CDFILLANC, IMPITMAF.NRAUTOFORN, IMPITMAF.CDPRODUTO, SUM(IMPITMAF.VRADIMPAF) AS VRIMPOSTO FROM IMPITMAF, AUTOFORNE WHERE AUTOFORNE.CDFILDEST = :P_CDFILDEST AND AUTOFORNE.CDFILLANC = :P_CDFILLANC AND AUTOFORNE.NRAUTOFORN = :P_NRAUTOFORN AND IMPITMAF.CDFILDEST = AUTOFORNE.CDFILDEST AND IMPITMAF.CDFILLANC = AUTOFORNE.CDFILLANC AND IMPITMAF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN GROUP BY IMPITMAF.CDFILDEST, IMPITMAF.CDFILLANC, IMPITMAF.NRAUTOFORN, IMPITMAF.CDPRODUTO ) IMPOSTO WHERE ITM_PROD.CDFILDEST = ITEMAUTF.CDFILDEST AND ITM_PROD.CDFILLANC = ITEMAUTF.CDFILLANC AND ITM_PROD.NRAUTOFORN = ITEMAUTF.NRAUTOFORN AND ITM_PROD.CDPRODUTO = ITEMAUTF.CDPRODUTO AND ITM_PROD.CDFILDEST = IMPOSTO.CDFILDEST (+) AND ITM_PROD.CDFILLANC = IMPOSTO.CDFILLANC (+) AND ITM_PROD.NRAUTOFORN = IMPOSTO.NRAUTOFORN(+) AND ITM_PROD.CDPRODUTO = IMPOSTO.CDPRODUTO (+) ) OR ( LIMGERPROD.VRLIMGPAFMES ) - ((ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF) - (( ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF * NVL(ITEMAUTF.VRPERDESAF,0) ) / 100) + NVL(IMP.VRIMPOSTO, 0)) < ( SELECT NVL(SUM(ITM_PROD.QTPROGENTAF * ITM_PROD.VRPREUNIAF) - SUM(( ITM_PROD.QTPROGENTAF * ITM_PROD.VRPREUNIAF * NVL( ITM_PROD.VRPERDESAF,0)) / 100) + SUM(NVL(IMPOSTO.VRIMPOSTO, 0) ), 0) FROM ITEMAUTF ITM_PROD, AUTOFORNE AF_MES, ( SELECT IMPITMAF.CDFILDEST, IMPITMAF.CDFILLANC, IMPITMAF.NRAUTOFORN, IMPITMAF.CDPRODUTO, SUM(IMPITMAF.VRADIMPAF) AS VRIMPOSTO FROM IMPITMAF, AUTOFORNE WHERE AUTOFORNE.CDGERENTE = :P_CDGERENTE AND IMPITMAF.CDFILDEST = AUTOFORNE.CDFILDEST AND IMPITMAF.CDFILLANC = AUTOFORNE.CDFILLANC AND IMPITMAF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN GROUP BY IMPITMAF.CDFILDEST, IMPITMAF.CDFILLANC, IMPITMAF.NRAUTOFORN, IMPITMAF.CDPRODUTO ) IMPOSTO WHERE AF_MES.CDGERENTE = :P_CDGERENTE AND TO_CHAR(AF_MES.DTAUTOFORN, 'MMYYYY') = TO_CHAR( AUTOFORNE.DTAUTOFORN, 'MMYYYY') AND ITM_PROD.CDFILDEST = AF_MES.CDFILDEST AND ITM_PROD.CDFILLANC = AF_MES.CDFILLANC AND ITM_PROD.NRAUTOFORN = AF_MES.NRAUTOFORN AND ITM_PROD.CDPRODUTO = ITEMAUTF.CDPRODUTO AND ITM_PROD.CDFILDEST = IMPOSTO.CDFILDEST (+) AND ITM_PROD.CDFILLANC = IMPOSTO.CDFILLANC (+) AND ITM_PROD.NRAUTOFORN = IMPOSTO.NRAUTOFORN(+) AND ITM_PROD.CDPRODUTO = IMPOSTO.CDPRODUTO (+) ) ) )";
        
        return self::executaSql($query, $params);
    }
    
    public function acmUpAFIncons($params) {
        $query = "UPDATE AUTOFORNE SET IDSITUATUAAF = NULL, IDAFFORALIM = 'N', CDGERENTE = :P_CDGERENTE, DSINCONSAF = '' WHERE CDFILDEST = :P_CDFILDEST AND CDFILLANC = :P_CDFILLANC AND NRAUTOFORN = :P_NRAUTOFORN";
        
        return self::executaSql($query, $params, false);
    }
    
    public function adqLimiteGerente($params) {
        $query = "SELECT AUTOFORNE.CDFILLANC, AUTOFORNE.CDFILDEST, AUTOFORNE.NRAUTOFORN FROM ( SELECT AUTOFORNE.CDFILDEST, AUTOFORNE.NRAUTOFORN, AUTOFORNE.CDFILLANC, AUTOFORNE.DTAUTOFORN FROM AUTOFORNE, GERENTE WHERE ( AUTOFORNE.CDFILDEST = :P_CDFILDEST ) AND ( AUTOFORNE.CDFILLANC = :P_CDFILLANC ) AND ( AUTOFORNE.NRAUTOFORN = :P_NRAUTOFORN ) AND ( GERENTE.CDOPERADOR = :P_CDGERENTE ) AND ( GERENTE.VRLIMIAFGER IS NULL OR GERENTE.VRLIMIAFGER >= AUTOFORNE.VRTOTALAF ) AND ( GERENTE.VRLIMAFMESG IS NULL OR GERENTE.VRLIMAFMESG >= ( SELECT SUM(AF_MES.VRTOTALAF) FROM AUTOFORNE AF_MES WHERE AF_MES.CDFILDEST = AUTOFORNE.CDFILDEST AND AF_MES.CDOPERADOR = AUTOFORNE.CDOPERADOR AND TO_CHAR(AF_MES.DTAUTOFORN, 'MMYYYY') = TO_CHAR( AUTOFORNE.DTAUTOFORN, 'MMYYYY') ) ) ) AUTOFORNE WHERE NOT EXISTS ( SELECT LIMGERPROD.CDPRODUTO FROM ITEMAUTF, LIMGERPROD, PRODUTO PL WHERE ITEMAUTF.CDFILDEST = :P_CDFILDEST AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN AND LIMGERPROD.CDOPERADOR = :P_CDGERENTE AND PL.CDPRODUTO = LIMGERPROD.CDPRODUTO AND PL.CDARVPROD = ( SELECT MAX(PRODUTO.CDARVPROD) FROM LIMGERPROD MAIOR_PROD, PRODUTO, PRODUTO P WHERE MAIOR_PROD.CDOPERADOR = :P_CDGERENTE AND PRODUTO.CDPRODUTO = MAIOR_PROD.CDPRODUTO AND P.CDPRODUTO = ITEMAUTF.CDPRODUTO AND P.CDARVPROD LIKE PRODUTO.CDARVPROD || '%' ) AND ( LIMGERPROD.VRLIMGPRODAF < ( SELECT SUM(ITM_PROD.QTPROGENTAF * ITM_PROD.VRPREUNIAF) - SUM(( ITM_PROD.QTPROGENTAF * ITM_PROD.VRPREUNIAF * NVL( ITM_PROD.VRPERDESAF,0)) / 100) + SUM(NVL(IMPOSTO.VRIMPOSTO, 0)) FROM ITEMAUTF ITM_PROD, ( SELECT IMPITMAF.CDFILDEST, IMPITMAF.CDFILLANC, IMPITMAF.NRAUTOFORN, IMPITMAF.CDPRODUTO, SUM(IMPITMAF.VRADIMPAF) AS VRIMPOSTO FROM IMPITMAF, AUTOFORNE WHERE AUTOFORNE.CDFILDEST = :P_CDFILDEST AND AUTOFORNE.CDFILLANC = :P_CDFILLANC AND AUTOFORNE.NRAUTOFORN = :P_NRAUTOFORN AND IMPITMAF.CDFILDEST = AUTOFORNE.CDFILDEST AND IMPITMAF.CDFILLANC = AUTOFORNE.CDFILLANC AND IMPITMAF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN GROUP BY IMPITMAF.CDFILDEST, IMPITMAF.CDFILLANC, IMPITMAF.NRAUTOFORN, IMPITMAF.CDPRODUTO ) IMPOSTO WHERE ITM_PROD.CDFILDEST = ITEMAUTF.CDFILDEST AND ITM_PROD.CDFILLANC = ITEMAUTF.CDFILLANC AND ITM_PROD.NRAUTOFORN = ITEMAUTF.NRAUTOFORN AND ITM_PROD.CDPRODUTO = ITEMAUTF.CDPRODUTO AND ITM_PROD.CDFILDEST = IMPOSTO.CDFILDEST (+) AND ITM_PROD.CDFILLANC = IMPOSTO.CDFILLANC (+) AND ITM_PROD.NRAUTOFORN = IMPOSTO.NRAUTOFORN(+) AND ITM_PROD.CDPRODUTO = IMPOSTO.CDPRODUTO (+) ) OR LIMGERPROD.VRLIMGPAFMES < ( SELECT SUM(ITM_PROD.QTPROGENTAF * ITM_PROD.VRPREUNIAF) - SUM(( ITM_PROD.QTPROGENTAF * ITM_PROD.VRPREUNIAF * NVL( ITM_PROD.VRPERDESAF,0)) / 100) + SUM(NVL(IMPOSTO.VRIMPOSTO, 0)) FROM ITEMAUTF ITM_PROD, AUTOFORNE AF_MES, ( SELECT IMPITMAF.CDFILDEST, IMPITMAF.CDFILLANC, IMPITMAF.NRAUTOFORN, IMPITMAF.CDPRODUTO, SUM(IMPITMAF.VRADIMPAF) AS VRIMPOSTO FROM IMPITMAF, AUTOFORNE WHERE AUTOFORNE.CDFILDEST = :P_CDFILDEST AND AUTOFORNE.CDOPERADOR = :P_CDOPERADOR AND IMPITMAF.CDFILDEST = AUTOFORNE.CDFILDEST AND IMPITMAF.CDFILLANC = AUTOFORNE.CDFILLANC AND IMPITMAF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN GROUP BY IMPITMAF.CDFILDEST, IMPITMAF.CDFILLANC, IMPITMAF.NRAUTOFORN, IMPITMAF.CDPRODUTO ) IMPOSTO WHERE AF_MES.CDFILDEST = :P_CDFILDEST AND AF_MES.CDOPERADOR = :P_CDOPERADOR AND TO_CHAR(AF_MES.DTAUTOFORN, 'MMYYYY') = TO_CHAR( AUTOFORNE.DTAUTOFORN, 'MMYYYY') AND ITM_PROD.CDFILDEST = AF_MES.CDFILDEST AND ITM_PROD.CDFILLANC = AF_MES.CDFILLANC AND ITM_PROD.NRAUTOFORN = AF_MES.NRAUTOFORN AND ITM_PROD.CDPRODUTO = ITEMAUTF.CDPRODUTO AND ITM_PROD.CDFILDEST = IMPOSTO.CDFILDEST (+) AND ITM_PROD.CDFILLANC = IMPOSTO.CDFILLANC (+) AND ITM_PROD.NRAUTOFORN = IMPOSTO.NRAUTOFORN(+) AND ITM_PROD.CDPRODUTO = IMPOSTO.CDPRODUTO (+) ) ) )";
        
        return self::executaSql($query, $params);
    }
    
    public function acmInsLista($params) {
        $query = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        
        return self::executaSql($query, $params, false);
    }
    
    public function acmDelLista($params) {
        $query = "DELETE FROM LISTA WHERE NRLISTA = :P_NRLISTA";
        
        return self::executaSql($query, $params, false);
    }
    
    public function adqTodasAF($params) {
        $query = "SELECT AUTOFORNE.CDFILDEST, AUTOFORNE.CDFILLANC, AUTOFORNE.NRAUTOFORN, AUTOFORNE.NRSEQAPURAF, AUTOFORNE.CDFORNECED FROM APURPRECO, AUTOFORNE WHERE AUTOFORNE.CDFILLANC = APURPRECO.CDFILCENTCMP AND AUTOFORNE.NRSEQAPURAF = APURPRECO.NRAPURPREC AND APURPRECO.IDSITAPUPREC = '1' AND NVL(:P_CDCOMPRADOR, AUTOFORNE.CDOPERADOR) = AUTOFORNE.CDOPERADOR AND (INSTR(:P_NRAPURPREC, APURPRECO.NRAPURPREC) > 0 OR :P_NRAPURPREC = 'T') AND (INSTR(:P_CDFORNECED, AUTOFORNE.CDFORNECED) > 0 OR :P_CDFORNECED = 'T') AND (INSTR(:P_CDFILIAL, AUTOFORNE.CDFILDEST) > 0 OR :P_CDFILIAL = 'T') AND APURPRECO.NRLOGCORTEOL IS NULL";
        
        return self::executaSql($query, $params);
    }
    
    public function acmDelAutoForne($params) {
        $query = "delete from AUTOFORNE where CDFILDEST = :OLD_CDFILDEST and CDFILLANC = :OLD_CDFILLANC and NRAUTOFORN = :OLD_NRAUTOFORN";
        
        return self::executaSql($query, $params, false);
    }
    
    public function acmDelEnvioAF($params) {
        $query = "DELETE FROM ENVIOAFFORN WHERE CDFORNECED = :P_CDFORNECED AND LISTNRSEQAPUR = :P_NRAPURPREC AND NOT EXISTS (SELECT 1 FROM AUTOFORNE WHERE CDFORNECED = :P_CDFORNECED AND CDFILDEST = :P_CDFILDEST AND CDFILLANC = :P_CDFILLANC AND NRSEQAPURAF = :P_NRAPURPREC AND NRSEQENVIOAFORN IS NOT NULL)";
        
        return self::executaSql($query, $params, false);
    }
    
    public function adqListaAF($params) {
        $query = "SELECT AUTOFORNE.CDFILDEST, AUTOFORNE.CDFILLANC, AUTOFORNE.NRAUTOFORN FROM LISTA LISTAAF, AUTOFORNE WHERE LISTAAF.NRLISTA = :P_NRLISTAAF AND SUBSTR(LISTAAF.CDLISTA, 1, 4) = AUTOFORNE.CDFILDEST AND SUBSTR(LISTAAF.CDLISTA, 5, 4) = AUTOFORNE.CDFILLANC AND SUBSTR(LISTAAF.CDLISTA, 9, 10) = AUTOFORNE.NRAUTOFORN";
        
        return self::executaSql($query, $params);
    }
    public function acmExcluiAF_Chave($params) {
        $query = "DELETE FROM AUTOFORNE WHERE AUTOFORNE.CDFILDEST = :P_CDFILDEST AND AUTOFORNE.CDFILLANC = :P_CDFILLANC AND AUTOFORNE.NRAUTOFORN = :P_NRAUTOFORN";
        
        return self::executaSql($query, $params, false);
    }
    public function acmDelItemAutF_Clone($params) {
        $query = "DELETE FROM ITEMAUTF_CLONE WHERE NRSEQAPURAF = :P_NRSEQAPURAF AND NRAUTOFORN = :P_NRAUTOFORN AND CDFILDEST = :P_CDFILDEST AND CDFILLANC = :P_CDFILLANC";
        
        return self::executaSql($query, $params, false);
    }
    
    public function retornaLinkPortalEcommerce($centralDeCompras) {
        $query = "SELECT DSLINKECOMMERCE FROM PARAMGERALECOMMERCE WHERE CDFILIAL = :P_CENTRALDECOMPRAS";
        
        $params = array(
            "P_CENTRALDECOMPRAS" => $centralDeCompras
        );
        
        $linkPortal = self::executaSql($query, $params);
        
        return is_array($linkPortal) && count($linkPortal) ? $linkPortal[0]['DSLINKECOMMERCE'] : false;
    }
    
    public function adqFornEnvia($cdfillanc, $nrseqapuraf) {
        $query = "SELECT DISTINCT A.CDFORNECED, F.NMFANTFORN, E.SGESTADO FROM AUTOFORNE A, FORNECEDOR F, ENDEFORN E WHERE ( A.CDFILLANC = :P_CDFILLANC ) AND ( A.NRSEQAPURAF = :P_NRSEQAPURAF ) AND ( F.CDFORNECED = A.CDFORNECED ) AND ( F.CDFORNECED = E.CDFORNECED(+) ) AND ( E.IDTPENDEFORN(+) = 'P' ) AND ( NVL(F.IDTPENVAFFOR, '1') = '1' )";
        
        $params = array(
            'P_CDFILLANC'   => $cdfillanc,
            'P_NRSEQAPURAF' => $nrseqapuraf
        );
        
        $fornEnvia = self::executaSql($query, $params);
        
        return is_array($fornEnvia) && count($fornEnvia) ? $fornEnvia[0] : false;
    }
    
    /*public function ($params) {
        $query = "";
        
        return self::executaSql($query, $params, false);
    }*/
    
    public function getQtFracionado($row) {
        $query = "SELECT APURPRECO.CDFILLANC, APURPRECO.NRAPURPREC, NVL(APURPRECO.IDQTFRACIONADO, 'N') IDQTFRACIONADO
                    FROM APURPRECO
                   WHERE APURPRECO.CDFILLANC = :P_CDFILIAL
                     AND APURPRECO.NRAPURPREC = :P_NRAPURPREC";
        $params = array(
            'P_CDFILIAL'   => $row['CDFILLANC'],
            'P_NRAPURPREC' => $row['NRAPURPREC']
        );
        
        return self::executaSql($query, $params);
    }
    
    public function getIdFuncaoFili($cdfilial) 
    {
        $query = "SELECT NRORG, CDFILIAL, NVL(IDFUNCAOFILI, '1') IDFUNCAOFILI FROM FILIAL WHERE INSTR(:P_CDFILIAL, CDFILIAL) > 0 AND NRORG = :NRORG";
        $params = array(
            'P_CDFILIAL' => $cdfilial,
            "NRORG"      => $this->environment->getNrOrg()
        );
        
        return self::executaSql($query, $params);
    }
    
    public function updateItemSoliRelacAF($row)
    {
        $update = "UPDATE ITEMSOLIRELACAF
                      SET DTPROGENTAF = :P_DTPROGENTNEW
                    WHERE ITEMSOLIRELACAF.CDFILDEST    = :P_CDFILDEST
                      AND ITEMSOLIRELACAF.CDFILLANC    = :P_CDFILLANC
                      AND ITEMSOLIRELACAF.NRAUTOFORN   = :P_NRAUTOFORN
                      AND ITEMSOLIRELACAF.CDMARCAAF    = :P_CDMARCA
                      AND ITEMSOLIRELACAF.CDPRODUTOAF  = :P_CDPRODUTO
                      AND ITEMSOLIRELACAF.DTPROGENTAF  = :P_DTPROGENTOLD
                      AND ITEMSOLIRELACAF.CDCENTITMAP  = :P_CDFILCENTCMP
                      AND ITEMSOLIRELACAF.NRSEQITMAP   = :P_NRSEQAPURAF
                      AND ITEMSOLIRELACAF.NRORG        = :NRORG
                      AND NOT EXISTS(SELECT 1
                                       FROM ITEMSOLIRELACAF R
                                      WHERE R.CDFILSOLI    = ITEMSOLIRELACAF.CDFILSOLI
                                        AND R.CDFILLAN     = ITEMSOLIRELACAF.CDFILLAN
                                        AND R.NRSOLICMP    = ITEMSOLIRELACAF.NRSOLICMP
                                        AND R.CDPRODUTO    = ITEMSOLIRELACAF.CDPRODUTO
                                        AND R.DTPROGENTR   = ITEMSOLIRELACAF.DTPROGENTR
                                        AND R.CDCENTITMAP  = :P_CDFILCENTCMP
                                        AND R.NRSEQITMAP   = :P_NRSEQAPURAF
                                        AND R.CDFILDEST    = :P_CDFILDEST
                                        AND R.CDFILLANC    = :P_CDFILLANC
                                        AND R.NRAUTOFORN   = :P_NRAUTOFORN
                                        AND R.CDMARCAAF    = :P_CDMARCA
                                        AND R.CDPRODUTOAF  = :P_CDPRODUTO
                                        AND R.DTPROGENTAF  = :P_DTPROGENTNEW
                                        AND R.NRORG        = :NRORG)";

        $params = [
            'P_CDFILCENTCMP' => $row['CDFILCENTCMP'],
            'P_NRSEQAPURAF'  => $row['NRAPURPREC'],
            'P_CDFILDEST'    => $row['CDFILDEST'],
            'P_CDFILLANC'    => $row['CDFILLANC'],
            'P_NRAUTOFORN'   => $row['NRAUTOFORN'],
            'P_CDMARCA'      => $row['CDMARCA'],
            'P_CDPRODUTO'    => $row['CDPRODUTO'],
            'P_DTPROGENTNEW' => $row['DTPROGENTAF'],
            'NRORG' => $this->environment->getNrOrg()
        ];
        
        return self::executaSql($update, $params, false);
    }
    
    public function updateQtSoliProd($itemsoli, $doQuantDife)
    {
        $update = "UPDATE ITEMSOLI 
                      SET QTSOLIPROD = QTSOLIPROD + :P_QTSOLIPROD
                    WHERE CDFILSOLI  = :P_CDFILSOLI
                      AND CDFILLAN   = :P_CDFILLAN
                      AND NRSOLICMP  = :P_NRSOLICMP
                      AND CDPRODUTO  = :P_CDPRODUTO
                      AND DTPROGENTR = :P_DTPROGENTR
                      AND NRORG      = :NRORG";

        $params = [
            'P_QTSOLIPROD' => $doQuantDife/$itemsoli['VRFATOSOLI'],
            'P_CDFILSOLI'  => $itemsoli['CDFILSOLI'],
            'P_CDFILLAN'   => $itemsoli['CDFILLAN'],
            'P_NRSOLICMP'  => $itemsoli['NRSOLICMP'],
            'P_CDPRODUTO'  => $itemsoli['CDPRODUTO'],
            'P_DTPROGENTR' => $itemsoli['DTPROGENTR'],
            'NRORG' => $this->environment->getNrOrg()
        ];

        return self::executaSql($update, $params, false);
    }
    
    public function updateQtSoliProdApu($row, $itemsoli, $doQuantDife)
    {
        $update = "UPDATE ITEMSOLIRELACAF
                      SET QTSOLIPROD = QTSOLIPROD + :P_QTSOLIPROD
                    WHERE CDFILSOLI   = :P_CDFILSOLI
                      AND CDFILLAN    = :P_CDFILLAN      
                      AND NRSOLICMP   = :P_NRSOLICMP
                      AND CDPRODUTO   = :P_CDPRODUTO
                      AND DTPROGENTR  = :P_DTPROGENTR
                      AND CDCENTITMAP = :P_CDFILCENTCMP
                      AND NRSEQITMAP  = :P_NRSEQAPURAF
                      AND CDFILDEST   = :P_CDFILDEST
                      AND CDFILLANC   = :P_CDFILLANC
                      AND NRAUTOFORN  = :P_NRAUTOFORN
                      AND CDMARCAAF   = :P_CDMARCA
                      AND CDPRODUTOAF = :P_CDPRODUTOAF
                      AND DTPROGENTAF = :P_DTPROGENTAF
                      AND NRORG       = :NRORG";

        $params = [
            'P_QTSOLIPROD'   => $doQuantDife/$itemsoli['VRFATOSOLI'],
            'P_CDFILSOLI'    => $itemsoli['CDFILSOLI'],
            'P_CDFILLAN'     => $itemsoli['CDFILLAN'],
            'P_NRSOLICMP'    => $itemsoli['NRSOLICMP'],
            'P_CDPRODUTO'    => $itemsoli['CDPRODUTO'],
            'P_DTPROGENTR'   => $itemsoli['DTPROGENTR'],
            
            'P_NRSEQAPURAF'  => $row['NRAPURPREC'],
            'P_CDFILCENTCMP' => $row['CDFILCENTCMP'],
            'P_CDFILDEST'    => $row['CDFILDEST'],
            'P_CDFILLANC'    => $row['CDFILLANC'],
            'P_NRAUTOFORN'   => $row['NRAUTOFORN'],
            'P_CDPRODUTOAF'  => $row['CDPRODUTO'],
            'P_CDMARCA'      => $row['CDMARCA'],
            'P_DTPROGENTAF'  => $row['DTPROGENTAF_OLD'],
            
            'NRORG' => $this->environment->getNrOrg()
        ];

        return self::executaSql($update, $params, false);
    }
    
    public function insertMovOpSol($row)
    {
        $insert = "INSERT INTO MOVOPSOL
                    (CDFILSOLMOV, CDFILLANMOV, NRSOLIMOV, CDPRODUTO, DTENTROPER,
                     DTOPERSOL, CDOPERADOR, QTANTOPER, QTDEPOPER, DSJUSTOPER,
                     IDOPERAMOVS, DSRDMUSUMOVS, DSENDUSUMOVS, DSNMUSUMOVS, 
                     DSMETUSUMOVS, NRORG)
                   VALUES
                    (:P_CDFILSOLMOV, :P_CDFILLANMOV, :P_NRSOLIMOV, :P_CDPRODUTO, 
                     :P_DTENTROPER, SYSDATE, :P_CDOPERADOR, :P_QTANTOPER, 
                     :P_QTDEPOPER, :P_DSJUSTOPER, :P_IDOPERAMOVS, 'ANALISE_AF', 'ZEEDHI', 
                     'ZEEDHI', 'ZEEDHI', :NRORG)";

        $params = [
            'P_CDFILSOLMOV' => $row['CDFILSOLI'],
            'P_CDFILLANMOV' => $row['CDFILLAN'],
            'P_NRSOLIMOV'   => $row['NRSOLICMP'],
            'P_CDPRODUTO'   => $row['CDPRODUTO'],
            'P_DTENTROPER'  => $row['DTPROGENTR'],
            'P_QTANTOPER'   => $row['QTSOLIPROD'],
            'P_QTDEPOPER'   => $row['QTDEPOPER'],
            'P_DSJUSTOPER'  => $row['DSJUSTOPER'],
            'P_IDOPERAMOVS' => $row['IDOPERAMOVS'],
            'P_CDOPERADOR'  => $this->environment->getCdOperador(),
            'NRORG'         => $this->environment->getNrOrg()
        ];

        return self::executaSql($insert, $params, false);
    }
    
    public function deleteItemSoli($row)
    {
         $delete = "DELETE FROM ITEMSOLI
                     WHERE CDFILSOLI  = :P_CDFILSOLI
                       AND CDFILLAN   = :P_CDFILLAN
                       AND NRSOLICMP  = :P_NRSOLICMP
                       AND CDPRODUTO  = :P_CDPRODUTO
                       AND DTPROGENTR = :P_DTPROGENTR
                       AND NRORG      = :NRORG";

        $params = [
            'P_CDFILSOLI'  => $row['CDFILSOLI'],
            'P_CDFILLAN'   => $row['CDFILLAN'],
            'P_NRSOLICMP'  => $row['NRSOLICMP'],
            'P_CDPRODUTO'  => $row['CDPRODUTO'],
            'P_DTPROGENTR' => $row['DTPROGENTR'],
            'NRORG'        => $this->environment->getNrOrg()
        ];

        return self::executaSql($delete, $params, false);
    }
    
    public function remanejaProcedure($afOrigem, $afDestino, $isProductSelected = false, $newProduct = false) 
    {
        $procedure = new StoredProcedure($this->connection, 'REMANEJAR_AF');
        
        /*Central de Compras*/
        $procedure->addParam(new Param('P_CDCENTCMP', Param::PARAM_INPUT, $afOrigem['CDFILCENTCMP'], Param::PARAM_TYPE_STR));
        /*Numero da apuracao de compras*/
        $procedure->addParam(new Param('P_NRSEQAPURAF', Param::PARAM_INPUT, $afOrigem['NRAPURPREC'], Param::PARAM_TYPE_STR));
        /*Filial de destino origem*/
        $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $afOrigem['CDFILDEST'], Param::PARAM_TYPE_STR));
        /*Filial de lancamento origem*/
        $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, $afOrigem['CDFILLANC'], Param::PARAM_TYPE_STR));
        /*Numero da AF origem*/
        $procedure->addParam(new Param('P_NRAUTOFORN', Param::PARAM_INPUT, $afOrigem['NRAUTOFORN'], Param::PARAM_TYPE_STR));
        /*Data de entrega da AF origem*/
        $procedure->addParam(new Param('P_DTPROGENTAF', Param::PARAM_INPUT, $afOrigem['DTPROGENTAF'], Param::PARAM_TYPE_STR));
        
        /*Numero da AF destino*/
        $procedure->addParam(new Param('P_NRAUTOFORN_DEST', Param::PARAM_INPUT, $afDestino['NRAUTOFORN'], Param::PARAM_TYPE_STR));
        /*Data de entrega da AF destino*/
        $procedure->addParam(new Param('P_DTPROGENTAF_DEST', Param::PARAM_INPUT, $afDestino['DTPROGENTAF'], Param::PARAM_TYPE_STR));
        /*Data de enterega do item de SC da AF destino*/
        $procedure->addParam(new Param('P_DTENTRITMSOL_DEST', Param::PARAM_INPUT, $afDestino['DTENTRITMSOL'], Param::PARAM_TYPE_STR));
        
        /********************************with defualt*****************************/
        
        /*Considera particularidade da filial destino da AF*/
        $procedure->addParam(new Param('P_PARTI', Param::PARAM_INPUT, $afDestino['CONSPARTFILDEST'], Param::PARAM_TYPE_STR));
        
        /*Marca do item da AF origem*/
        
        $procedure->addParam(new Param('P_CDMARCA', Param::PARAM_INPUT, $isProductSelected ? $afOrigem['CDMARCA'] : null, Param::PARAM_TYPE_STR));
        /*Codigo do produto do item de AF origem*/
        $procedure->addParam(new Param('P_CDPRODUTO', Param::PARAM_INPUT, $isProductSelected ? $afOrigem['CDPRODUTO'] : null, Param::PARAM_TYPE_STR));
        /*Marca do item da AF destino*/
        $procedure->addParam(new Param('P_CDMARCA_DEST', Param::PARAM_INPUT, $newProduct ? $newProduct['CDMARCA'] : null, Param::PARAM_TYPE_STR));
        /*Codigo do produto do item de AF destino*/
        $procedure->addParam(new Param('P_CDPRODUTO_DEST', Param::PARAM_INPUT, $newProduct ? $newProduct['CDPRODUTO'] : null, Param::PARAM_TYPE_STR));
        
        $procedure->addParam(new Param('P_RESULT_ERROS', Param::PARAM_OUTPUT,  null, null, 32000));

        return $procedure->execute();
    }
    
    public function getFornecedor($row) {
        $query = "SELECT NMFANTFORN, NMRAZSOCFORN, NRINSJURFORN, CDFORNECED
                    FROM FORNECEDOR
                   WHERE CDFORNECED = :P_CDFORNECED
                     AND NRORG = :NRORG";
        $params = array(
            'P_CDFORNECED' => $row['CDFORNECED'],
            'NRORG'        => $this->environment->getNrOrg()
        );
        
        return self::executaSql($query, $params);
    }
    
    public function getProduto($produto) {
        $query = "SELECT CDARVPROD, CDPRODUTO, NMPRODUTO
                    FROM PRODUTO
                   WHERE CDPRODUTO = :P_CDPRODUTO
                     AND NRORG = :NRORG";
        $params = array(
            'P_CDPRODUTO' => $produto,
            'NRORG'        => $this->environment->getNrOrg()
        );
        
        return self::executaSql($query, $params);
    }
}